#install packages
install.packages(c("foreign","psych","stringr","lme4","data.table"))

#load packages
library(foreign, pos=4)
library(psych)
library(stringr)
library(lme4)
library(data.table)

#read data
dat <- read.spss("http://madata.bib.uni-mannheim.de/333/3/B5FacetsRelig_Study3_data.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)

#residualize and z-standardize level-1 predictors
##number cities from 1 to 2176
dat$ara_num <- str_remove(str_sub(dat$ara, 7), "^0+")

##Big Five facets without one specific Big Five nuance
num.ara <- 2176
sample.ara <- 0

dat3 <- data.frame(id=NA, cnt=NA, sta=NA, ara=NA, relig=NA,
                   res_altr_no_agr02=NA, res_altr_no_agr05=NA,
                   res_altr_no_agr06r=NA, res_altr_no_agr07=NA,
                   res_comp_no_agr01r=NA, res_comp_no_agr03r=NA,
                   res_comp_no_agr04=NA, res_disc_no_cns03=NA,
                   res_disc_no_cns05r=NA, res_disc_no_cns06=NA,
                   res_disc_no_cns08=NA, res_disc_no_cns09r=NA,
                   res_asse_no_ext01=NA, res_asse_no_ext02r=NA,
                   res_asse_no_ext05r=NA, res_asse_no_ext06=NA,
                   res_asse_no_ext07r=NA, res_idea_no_opn02=NA,
                   res_idea_no_opn03=NA, res_idea_no_opn05=NA,
                   res_idea_no_opn07r=NA, res_idea_no_opn08=NA,
                   res_aest_no_opn06=NA, res_aest_no_opn09r=NA,
                   res_aest_no_opn10=NA, res_anxi_no_neu02r=NA,
                   res_anxi_no_neu04=NA, res_anxi_no_neu07r=NA,
                   res_anxi_no_neu08=NA) [numeric(0), ]

for (i in 1:num.ara) {
  
  sample.ara <- sample.ara + 1
  dat1 <- subset(dat, subset = ara_num == sample.ara)
  
  m1 <- lm(altr_no_agr02 ~  comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_altr_no_agr02 <- residuals(m1)
  
  m2 <- lm(altr_no_agr05 ~  comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_altr_no_agr05 <- residuals(m2)
  
  m3 <- lm(altr_no_agr06r ~  comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_altr_no_agr06r <- residuals(m3)
  
  m4 <- lm(altr_no_agr07 ~  comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_altr_no_agr07 <- residuals(m4)
  
  m5 <- lm(comp_no_agr01r ~  altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_comp_no_agr01r <- residuals(m5)
  
  m6 <- lm(comp_no_agr03r ~  altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_comp_no_agr03r <- residuals(m6)
  
  m7 <- lm(comp_no_agr04 ~  altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_comp_no_agr04 <- residuals(m7)
  
  m8 <- lm(disc_no_cns03 ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc_no_cns03 <- residuals(m8)
  
  m9 <- lm(disc_no_cns05r ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc_no_cns05r <- residuals(m9)
  
  m10 <- lm(disc_no_cns06 ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc_no_cns06 <- residuals(m10)
  
  m11 <- lm(disc_no_cns08 ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc_no_cns08 <- residuals(m11)
  
  m12 <- lm(disc_no_cns09r ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc_no_cns09r <- residuals(m12)
  
  m13 <- lm(asse_no_ext01 ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse_no_ext01 <- residuals(m13)
  
  m14 <- lm(asse_no_ext02r ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse_no_ext02r <- residuals(m14)
  
  m15 <- lm(asse_no_ext05r ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse_no_ext05r <- residuals(m15)
  
  m16 <- lm(asse_no_ext06 ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse_no_ext06 <- residuals(m16)
  
  m17 <- lm(asse_no_ext07r ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse_no_ext07r <- residuals(m17)
  
  m18 <- lm(idea_no_opn02 ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea_no_opn02 <- residuals(m18)
  
  m19 <- lm(idea_no_opn03 ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea_no_opn03 <- residuals(m19)
  
  m20 <- lm(idea_no_opn05 ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea_no_opn05 <- residuals(m20)
  
  m21 <- lm(idea_no_opn07r ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea_no_opn07r <- residuals(m21)
  
  m22 <- lm(idea_no_opn08 ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea_no_opn08 <- residuals(m22)
  
  m23 <- lm(aest_no_opn06 ~  altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_aest_no_opn06 <- residuals(m23)
  
  m24 <- lm(aest_no_opn09r ~  altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_aest_no_opn09r <- residuals(m24)
  
  m25 <- lm(aest_no_opn10 ~  altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_aest_no_opn10 <- residuals(m25)
  
  m26 <- lm(anxi_no_neu02r ~  altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_anxi_no_neu02r <- residuals(m26)
  
  m27 <- lm(anxi_no_neu04 ~  altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_anxi_no_neu04 <- residuals(m27)
  
  m28 <- lm(anxi_no_neu07r ~  altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_anxi_no_neu07r <- residuals(m28)
  
  m29 <- lm(anxi_no_neu08 ~  altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_anxi_no_neu08 <- residuals(m29)
  
  dat2 <- cbind(dat1$record_id,dat1$cnt,dat1$sta,dat1$ara,dat1$relig,
                dat1$res_altr_no_agr02,dat1$res_altr_no_agr05,
                dat1$res_altr_no_agr06r,dat1$res_altr_no_agr07,
                dat1$res_comp_no_agr01r,dat1$res_comp_no_agr03r,
                dat1$res_comp_no_agr04,dat1$res_disc_no_cns03,
                dat1$res_disc_no_cns05r,dat1$res_disc_no_cns06,
                dat1$res_disc_no_cns08,dat1$res_disc_no_cns09r,
                dat1$res_asse_no_ext01,dat1$res_asse_no_ext02r,
                dat1$res_asse_no_ext05r,dat1$res_asse_no_ext06,
                dat1$res_asse_no_ext07r,dat1$res_idea_no_opn02,
                dat1$res_idea_no_opn03,dat1$res_idea_no_opn05,
                dat1$res_idea_no_opn07r,dat1$res_idea_no_opn08,
                dat1$res_aest_no_opn06,dat1$res_aest_no_opn09r,
                dat1$res_aest_no_opn10,dat1$res_anxi_no_neu02r,
                dat1$res_anxi_no_neu04,dat1$res_anxi_no_neu07r,
                dat1$res_anxi_no_neu08)
  cols_dat2 <- c("id","cnt","sta","ara","relig",
                 "res_altr_no_agr02","res_altr_no_agr05",
                 "res_altr_no_agr06r","res_altr_no_agr07",
                 "res_comp_no_agr01r","res_comp_no_agr03r",
                 "res_comp_no_agr04","res_disc_no_cns03",
                 "res_disc_no_cns05r","res_disc_no_cns06",
                 "res_disc_no_cns08","res_disc_no_cns09r",
                 "res_asse_no_ext01","res_asse_no_ext02r",
                 "res_asse_no_ext05r","res_asse_no_ext06",
                 "res_asse_no_ext07r","res_idea_no_opn02",
                 "res_idea_no_opn03","res_idea_no_opn05",
                 "res_idea_no_opn07r","res_idea_no_opn08",
                 "res_aest_no_opn06","res_aest_no_opn09r",
                 "res_aest_no_opn10","res_anxi_no_neu02r",
                 "res_anxi_no_neu04","res_anxi_no_neu07r",
                 "res_anxi_no_neu08")
  colnames(dat2) <- cols_dat2
  
  dat3 <- rbind(dat3, dat2)
  
}

dat3$zres_altr_no_agr02 <- scale(dat3$res_altr_no_agr02)
dat3$zres_altr_no_agr05 <- scale(dat3$res_altr_no_agr05)
dat3$zres_altr_no_agr06r <- scale(dat3$res_altr_no_agr06r)
dat3$zres_altr_no_agr07 <- scale(dat3$res_altr_no_agr07)
dat3$zres_comp_no_agr01r <- scale(dat3$res_comp_no_agr01r)
dat3$zres_comp_no_agr03r <- scale(dat3$res_comp_no_agr03r)
dat3$zres_comp_no_agr04 	<- scale(dat3$res_comp_no_agr04)
dat3$zres_disc_no_cns03 	<- scale(dat3$res_disc_no_cns03)
dat3$zres_disc_no_cns05r <- scale(dat3$res_disc_no_cns05r)
dat3$zres_disc_no_cns06 	<- scale(dat3$res_disc_no_cns06)
dat3$zres_disc_no_cns08 	<- scale(dat3$res_disc_no_cns08)
dat3$zres_disc_no_cns09r <- scale(dat3$res_disc_no_cns09r)
dat3$zres_asse_no_ext01 	<- scale(dat3$res_asse_no_ext01)
dat3$zres_asse_no_ext02r <- scale(dat3$res_asse_no_ext02r)
dat3$zres_asse_no_ext05r <- scale(dat3$res_asse_no_ext05r)
dat3$zres_asse_no_ext06 	<- scale(dat3$res_asse_no_ext06)
dat3$zres_asse_no_ext07r <- scale(dat3$res_asse_no_ext07r)
dat3$zres_idea_no_opn02 	<- scale(dat3$res_idea_no_opn02)
dat3$zres_idea_no_opn03 	<- scale(dat3$res_idea_no_opn03)
dat3$zres_idea_no_opn05 	<- scale(dat3$res_idea_no_opn05)
dat3$zres_idea_no_opn07r <- scale(dat3$res_idea_no_opn07r)
dat3$zres_idea_no_opn08 	<- scale(dat3$res_idea_no_opn08)
dat3$zres_aest_no_opn06 	<- scale(dat3$res_aest_no_opn06)
dat3$zres_aest_no_opn09r <- scale(dat3$res_aest_no_opn09r)
dat3$zres_aest_no_opn10 	<- scale(dat3$res_aest_no_opn10)
dat3$zres_anxi_no_neu02r <- scale(dat3$res_anxi_no_neu02r)
dat3$zres_anxi_no_neu04 	<- scale(dat3$res_anxi_no_neu04)
dat3$zres_anxi_no_neu07r <- scale(dat3$res_anxi_no_neu07r)
dat3$zres_anxi_no_neu08	<- scale(dat3$res_anxi_no_neu08)

dat_mplus_facets <- subset(dat3, select = c(id,cnt,sta,ara,relig,zres_altr_no_agr02:zres_anxi_no_neu08))

rm(dat1,dat2,dat3,m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16,m17,m18,m19,m20,
   m21,m22,m23,m24,m25,m26,m27,m28,m29,cols_dat2,i,num.ara,sample.ara)

##Big Five nuances
num.ara <- 2176
sample.ara <- 0

dat3 <- data.frame(id=NA, res_agr01r=NA, res_agr02=NA,
                   res_agr03r=NA, res_agr04=NA, 
                   res_agr05=NA, res_agr06r=NA,
                   res_agr07=NA, res_cns02r=NA,
                   res_cns03=NA, res_cns04r=NA,
                   res_cns05r=NA, res_cns06=NA,
                   res_cns08=NA, res_cns09r=NA,
                   res_ext01=NA, res_ext02r=NA,
                   res_ext03=NA, res_ext04=NA,
                   res_ext05r=NA, res_ext06=NA,
                   res_ext07r=NA, res_neu01=NA,
                   res_neu02r=NA, res_neu04=NA,
                   res_neu06=NA, res_neu07r=NA,
                   res_neu08=NA, res_opn02=NA,
                   res_opn03=NA, res_opn05=NA,
                   res_opn06=NA, res_opn07r=NA,
                   res_opn08=NA, res_opn09r=NA,
                   res_opn10=NA) [numeric(0), ]

for (i in 1:num.ara) {
  
  sample.ara <- sample.ara + 1
  dat1 <- subset(dat, subset = ara_num == sample.ara)
  
  m1 <- lm(ext01 ~ altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext01 <- residuals(m1)
  
  m2 <- lm(agr01r ~ altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr01r <- residuals(m2)
  
  m3 <- lm(neu01 ~ altr + comp + orde + disc +  acti + asse + idea +  aest +  anxi, data=dat1)
  dat1$res_neu01 <- residuals(m3)
  
  m4 <- lm(ext02r ~ altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext02r <- residuals(m4)
  
  m5 <- lm(agr02 ~ comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr02 <- residuals(m5)
  
  m6 <- lm(cns02r ~ altr + comp +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns02r <- residuals(m6)
  
  m7 <- lm(neu02r ~ altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_neu02r <- residuals(m7)
  
  m8 <- lm(opn02 ~ altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_opn02 <- residuals(m8)
  
  m9 <- lm(ext03 ~ altr + comp + orde + disc +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext03 <- residuals(m9)
  
  m10 <- lm(agr03r ~ altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr03r <- residuals(m10)
  
  m11 <- lm(cns03 ~ altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns03 <- residuals(m11)
  
  m12 <- lm(opn03 ~ altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_opn03 <- residuals(m12)
  
  m13 <- lm(ext04 ~ altr + comp + orde + disc +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext04 <- residuals(m13)
  
  m14 <- lm(agr04 ~ altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr04 <- residuals(m14)
  
  m15 <- lm(cns04r ~ altr + comp +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns04r <- residuals(m15)
  
  m16 <- lm(neu04 ~ altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_neu04 <- residuals(m16)
  
  m17 <- lm(ext05r ~ altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext05r <- residuals(m17)
  
  m18 <- lm(agr05 ~ comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr05 <- residuals(m18)
  
  m19 <- lm(cns05r ~ altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns05r <- residuals(m19)
  
  m20 <- lm(opn05 ~ altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_opn05 <- residuals(m20)
  
  m21 <- lm(ext06 ~ altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext06 <- residuals(m21)
  
  m22 <- lm(agr06r ~ comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr06r <- residuals(m22)
  
  m23 <- lm(cns06 ~ altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns06 <- residuals(m23)
  
  m24 <- lm(neu06 ~ altr + comp + orde + disc +  acti + asse + idea +  aest +  anxi, data=dat1)
  dat1$res_neu06 <- residuals(m24)
  
  m25 <- lm(opn06 ~ altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_opn06 <- residuals(m25)
  
  m26 <- lm(ext07r ~ altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_ext07r <- residuals(m26)
  
  m27 <- lm(agr07 ~ comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_agr07 <- residuals(m27)
  
  m28 <- lm(neu07r ~ altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_neu07r <- residuals(m28)
  
  m29 <- lm(opn07r ~ altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_opn07r <- residuals(m29)
  
  m30 <- lm(cns08 ~ altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns08 <- residuals(m30)
  
  m31 <- lm(neu08 ~ altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_neu08 <- residuals(m31)
  
  m32 <- lm(opn08 ~ altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_opn08 <- residuals(m32)
  
  m33 <- lm(opn09r ~ altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_opn09r <- residuals(m33)
  
  m34 <- lm(cns09r ~ altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_cns09r <- residuals(m34)
  
  m35 <- lm(opn10 ~ altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_opn10 <- residuals(m35)
  
  dat2 <- cbind(dat1$record_id,dat1$res_agr01r, dat1$res_agr02,
                dat1$res_agr03r, dat1$res_agr04, 
                dat1$res_agr05, dat1$res_agr06r,
                dat1$res_agr07, dat1$res_cns02r,
                dat1$res_cns03, dat1$res_cns04r,
                dat1$res_cns05r, dat1$res_cns06,
                dat1$res_cns08, dat1$res_cns09r,
                dat1$res_ext01, dat1$res_ext02r,
                dat1$res_ext03, dat1$res_ext04,
                dat1$res_ext05r, dat1$res_ext06,
                dat1$res_ext07r, dat1$res_neu01,
                dat1$res_neu02r, dat1$res_neu04,
                dat1$res_neu06, dat1$res_neu07r,
                dat1$res_neu08, dat1$res_opn02,
                dat1$res_opn03, dat1$res_opn05,
                dat1$res_opn06, dat1$res_opn07r,
                dat1$res_opn08, dat1$res_opn09r,
                dat1$res_opn10)
  cols_dat2 <- c("id","res_agr01r", "res_agr02",
                 "res_agr03r", "res_agr04", 
                 "res_agr05", "res_agr06r",
                 "res_agr07", "res_cns02r",
                 "res_cns03", "res_cns04r",
                 "res_cns05r", "res_cns06",
                 "res_cns08", "res_cns09r",
                 "res_ext01", "res_ext02r",
                 "res_ext03", "res_ext04",
                 "res_ext05r", "res_ext06",
                 "res_ext07r", "res_neu01",
                 "res_neu02r", "res_neu04",
                 "res_neu06", "res_neu07r",
                 "res_neu08", "res_opn02",
                 "res_opn03", "res_opn05",
                 "res_opn06", "res_opn07r",
                 "res_opn08", "res_opn09r",
                 "res_opn10")
  colnames(dat2) <- cols_dat2
  
  dat3 <- rbind(dat3, dat2)
  
}

dat3$zres_agr01r <- scale(dat3$res_agr01r)
dat3$zres_agr02 <- scale(dat3$res_agr02)
dat3$zres_agr03r <- scale(dat3$res_agr03r)
dat3$zres_agr04 <- scale(dat3$res_agr04)
dat3$zres_agr05 <- scale(dat3$res_agr05)
dat3$zres_agr06r <- scale(dat3$res_agr06r)
dat3$zres_agr07 <- scale(dat3$res_agr07)
dat3$zres_cns02r <- scale(dat3$res_cns02r)
dat3$zres_cns03 <- scale(dat3$res_cns03)
dat3$zres_cns04r <- scale(dat3$res_cns04r)
dat3$zres_cns05r <- scale(dat3$res_cns05r)
dat3$zres_cns06 <- scale(dat3$res_cns06)
dat3$zres_cns08 <- scale(dat3$res_cns08)
dat3$zres_cns09r <- scale(dat3$res_cns09r)
dat3$zres_ext01 <- scale(dat3$res_ext01)
dat3$zres_ext02r <- scale(dat3$res_ext02r)
dat3$zres_ext03 <- scale(dat3$res_ext03)
dat3$zres_ext04 <- scale(dat3$res_ext04)
dat3$zres_ext05r <- scale(dat3$res_ext05r)
dat3$zres_ext06 <- scale(dat3$res_ext06)
dat3$zres_ext07r <- scale(dat3$res_ext07r)
dat3$zres_neu01 <- scale(dat3$res_neu01)
dat3$zres_neu02r <- scale(dat3$res_neu02r)
dat3$zres_neu04 <- scale(dat3$res_neu04)
dat3$zres_neu06 <- scale(dat3$res_neu06)
dat3$zres_neu07r <- scale(dat3$res_neu07r)
dat3$zres_neu08 <- scale(dat3$res_neu08)
dat3$zres_opn02 <- scale(dat3$res_opn02)
dat3$zres_opn03 <- scale(dat3$res_opn03)
dat3$zres_opn05 <- scale(dat3$res_opn05)
dat3$zres_opn06 <- scale(dat3$res_opn06)
dat3$zres_opn07r <- scale(dat3$res_opn07r)
dat3$zres_opn08 <- scale(dat3$res_opn08)
dat3$zres_opn09r <- scale(dat3$res_opn09r)
dat3$zres_opn10 <- scale(dat3$res_opn10)

dat_mplus_nuances <- subset(dat3, select = c(id,zres_agr01r:zres_opn10))

rm(dat1,dat2,dat3,m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16,m17,m18,m19,m20,
   m21,m22,m23,m24,m25,m26,m27,m28,m29,m30,m31,m32,m33,m34,m35,cols_dat2,i,num.ara,sample.ara)

dat_mplus <- merge(dat_mplus_facets, dat_mplus_nuances, by = "id", all = TRUE)

#group-mean center and z-standardize level-2 predictor
dat2 <- aggregate(cbind(sta, relig) ~ ara, dat_mplus, mean)
dat2$zarelgrp <- scale(dat2$relig - ave(dat2$relig, dat2$sta))
dat2$sta <- NULL
dat2$relig <- NULL
dat_mplus <- merge(dat_mplus, dat2, by = "ara", all = TRUE)
rm(dat2)

#group-mean center and z-standardize level-3 predictor
dat3 <- aggregate(cbind(cnt, relig) ~ sta, dat_mplus, mean)
dat3$zsrelgrp <- scale(dat3$relig - ave(dat3$relig, dat3$cnt))
dat3$cnt <- NULL
dat3$relig <- NULL
dat_mplus <- merge(dat_mplus, dat3, by = "sta", all = TRUE)
rm(dat3)

#compute level-4 predictor (z-standardized on Level 4)
dat4 <- aggregate(relig ~ cnt, dat_mplus, mean)
dat4$zcrel <- scale(dat4$relig)
dat4$relig <- NULL
dat_mplus <- merge(dat_mplus, dat4, by = "cnt", all = TRUE)
rm(dat4)

# z-standardize criterion
dat_mplus$zprel <- scale(dat_mplus$relig)

#select variables for indirect-effects analyses in Mplus
dat_mplus <- subset(dat_mplus, select = c(id,cnt,sta,ara,zprel,zcrel,zsrelgrp,zarelgrp,zres_agr01r:zres_opn10,zres_altr_no_agr02:zres_anxi_no_neu08))

##set working directory to the folder to which the dataset should be saved (e.g., "C:/B5FacetsRelig") and save data
setwd("C:/B5FacetsRelig")
fwrite(dat_mplus, file = "B5FacetsRelig_Study3_mplus-data.csv", col.names = FALSE)
