#install packages
install.packages(c("foreign","psych","stringr","lme4","data.table"))

#load packages
library(foreign, pos=4)
library(psych)
library(stringr)
library(lme4)
library(data.table)

#read data
dat <- read.spss("http://madata.bib.uni-mannheim.de/333/3/B5FacetsRelig_Study3_data.sav", use.value.labels=FALSE, max.value.labels=inf, to.data.frame=TRUE)

#residualize and z-standardize level-1 predictors
##number cities from 1 to 2176
dat$ara_num <- str_remove(str_sub(dat$ara, 7), "^0+")

##Big Five facets
num.ara <- 2176
sample.ara <- 0

dat3 <- data.frame(id=NA, cnt=NA, sta=NA, ara=NA, relig=NA,
                   res_altr=NA, res_comp=NA,
                   res_orde=NA, res_disc=NA, 
                   res_acti=NA, res_asse=NA,
                   res_idea=NA, res_aest=NA,
                   res_depr=NA, res_anxi=NA) [numeric(0), ]

for (i in 1:num.ara) {
  
  sample.ara <- sample.ara + 1
  dat1 <- subset(dat, subset = ara_num == sample.ara)
  
  m1 <- lm(altr ~  comp +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_altr <- residuals(m1)
  
  m2 <- lm(comp ~  altr +  orde +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_comp <- residuals(m2)
  
  m3 <- lm(orde ~  altr + comp +  disc +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_orde <- residuals(m3)
  
  m4 <- lm(disc ~  altr + comp + orde +  acti +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_disc <- residuals(m4)
  
  m5 <- lm(acti ~  altr + comp + orde + disc +  asse +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_acti <- residuals(m5)
  
  m6 <- lm(asse ~  altr + comp + orde + disc +  acti +  idea +  aest +  depr +  anxi, data=dat1)
  dat1$res_asse <- residuals(m6)
  
  m7 <- lm(idea ~  altr + comp + orde + disc +  acti + asse +  aest +  depr +  anxi, data=dat1)
  dat1$res_idea <- residuals(m7)
  
  m8 <- lm(aest ~  altr + comp + orde + disc +  acti + asse + idea +  depr +  anxi, data=dat1)
  dat1$res_aest <- residuals(m8)
  
  m9 <- lm(depr ~  altr + comp + orde + disc +  acti + asse + idea +  aest +  anxi, data=dat1)
  dat1$res_depr <- residuals(m9)
  
  m10 <- lm(anxi ~  altr + comp + orde + disc +  acti + asse + idea +  aest + depr, data=dat1)
  dat1$res_anxi <- residuals(m10)
  
  dat2 <- cbind(dat1$record_id,dat1$cnt,dat1$sta,dat1$ara,dat1$relig,
                dat1$res_altr,dat1$res_comp,
                dat1$res_orde,dat1$res_disc,
                dat1$res_acti,dat1$res_asse,
                dat1$res_idea,dat1$res_aest,
                dat1$res_depr,dat1$res_anxi)
  cols_dat2 <- c("id","cnt","sta","ara","relig",
                 "res_altr","res_comp","res_orde","res_disc",
                "res_acti","res_asse","res_idea","res_aest",
                "res_depr","res_anxi")
  colnames(dat2) <- cols_dat2
  
  dat3 <- rbind(dat3, dat2)
  
  }

dat3$zres_altr <- scale(dat3$res_altr)
dat3$zres_comp <- scale(dat3$res_comp)
dat3$zres_orde <- scale(dat3$res_orde)
dat3$zres_disc <- scale(dat3$res_disc)
dat3$zres_acti <- scale(dat3$res_acti)
dat3$zres_asse <- scale(dat3$res_asse)
dat3$zres_aest <- scale(dat3$res_aest)
dat3$zres_idea <- scale(dat3$res_idea)
dat3$zres_anxi <- scale(dat3$res_anxi)
dat3$zres_depr <- scale(dat3$res_depr)

dat_facets <- dat3

rm(dat1,dat2,dat3,m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,cols_dat2,i,num.ara,sample.ara)

##Big Five nuances
num.ara <- 2176
sample.ara <- 0

dat3 <- data.frame(id=NA, cnt=NA, sta=NA, ara=NA, relig=NA,
                   res_agr01r=NA, res_agr02=NA,
                   res_agr03r=NA, res_agr04=NA, 
                   res_agr05=NA, res_agr06r=NA,
                   res_agr07=NA, res_cns02r=NA,
                   res_cns03=NA, res_cns04r=NA,
                   res_cns05r=NA, res_cns06=NA,
                   res_cns08=NA, res_cns09r=NA,
                   res_ext01=NA, res_ext02r=NA,
                   res_ext03=NA, res_ext04=NA,
                   res_ext05r=NA, res_ext06=NA,
                   res_ext07r=NA, res_neu01=NA,
                   res_neu02r=NA, res_neu04=NA,
                   res_neu06=NA, res_neu07r=NA,
                   res_neu08=NA, res_opn02=NA,
                   res_opn03=NA, res_opn05=NA,
                   res_opn06=NA, res_opn07r=NA,
                   res_opn08=NA, res_opn09r=NA,
                   res_opn10=NA) [numeric(0), ]

for (i in 1:num.ara) {
  
  sample.ara <- sample.ara + 1
  dat1 <- subset(dat, subset = ara_num == sample.ara)
  
  m1 <- lm(ext01 ~ agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext01 <- residuals(m1)
  
  m2 <- lm(agr01r ~ ext01 + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr01r <- residuals(m2)
  
  m3 <- lm(neu01 ~ ext01 + agr01r + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu01 <- residuals(m3)
  
  m4 <- lm(ext02r ~ ext01 + agr01r + neu01 + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext02r <- residuals(m4)
  
  m5 <- lm(agr02 ~ ext01 + agr01r + neu01 + ext02r + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr02 <- residuals(m5)
  
  m6 <- lm(cns02r ~ ext01 + agr01r + neu01 + ext02r + agr02 + neu02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns02r <- residuals(m6)
  
  m7 <- lm(neu02r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + opn02 + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu02r <- residuals(m7)
  
  m8 <- lm(opn02 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + ext03 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn02 <- residuals(m8)
  
  m9 <- lm(ext03 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + agr03r + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext03 <- residuals(m9)
  
  m10 <- lm(agr03r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + cns03 + 
             opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
             opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr03r <- residuals(m10)
  
  m11 <- lm(cns03 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + 
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns03 <- residuals(m11)
  
  m12 <- lm(opn03 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn03 <- residuals(m12)
  
  m13 <- lm(ext04 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext04 <- residuals(m13)
  
  m14 <- lm(agr04 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr04 <- residuals(m14)
  
  m15 <- lm(cns04r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns04r <- residuals(m15)
  
  m16 <- lm(neu04 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu04 <- residuals(m16)
  
  m17 <- lm(ext05r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext05r <- residuals(m17)
  
  m18 <- lm(agr05 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr05 <- residuals(m18)
  
  m19 <- lm(cns05r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns05r <- residuals(m19)
  
  m20 <- lm(opn05 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn05 <- residuals(m20)
  
  m21 <- lm(ext06 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext06 <- residuals(m21)
  
  m22 <- lm(agr06r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr06r <- residuals(m22)
  
  m23 <- lm(cns06 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns06 <- residuals(m23)
  
  m24 <- lm(neu06 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu06 <- residuals(m24)
  
  m25 <- lm(opn06 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn06 <- residuals(m25)
  
  m26 <- lm(ext07r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_ext07r <- residuals(m26)
  
  m27 <- lm(agr07 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_agr07 <- residuals(m27)
  
  m28 <- lm(neu07r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu07r <- residuals(m28)
  
  m29 <- lm(opn07r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + cns08 + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn07r <- residuals(m29)
  
  m30 <- lm(cns08 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + neu08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_cns08 <- residuals(m30)
  
  m31 <- lm(neu08 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + opn08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_neu08 <- residuals(m31)
  
  m32 <- lm(opn08 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn09r + cns09r + opn10, data=dat1)
  dat1$res_opn08 <- residuals(m32)
  
  m33 <- lm(opn09r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + cns09r + opn10, data=dat1)
  dat1$res_opn09r <- residuals(m33)
  
  m34 <- lm(cns09r ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + opn10, data=dat1)
  dat1$res_cns09r <- residuals(m34)
  
  m35 <- lm(opn10 ~ ext01 + agr01r + neu01 + ext02r + agr02 + cns02r + neu02r + opn02 + ext03 + agr03r + cns03 +
              opn03 + ext04 + agr04 + cns04r + neu04 + ext05r + agr05 + cns05r + opn05 + ext06 + agr06r + cns06 + neu06 + 
              opn06 + ext07r + agr07 + neu07r + opn07r + cns08 + neu08 + opn08 + opn09r + cns09r, data=dat1)
  dat1$res_opn10 <- residuals(m35)
  
  dat2 <- cbind(dat1$record_id,dat1$cnt,dat1$sta,dat1$ara,dat1$relig,
                dat1$res_agr01r, dat1$res_agr02,
                dat1$res_agr03r, dat1$res_agr04, 
                dat1$res_agr05, dat1$res_agr06r,
                dat1$res_agr07, dat1$res_cns02r,
                dat1$res_cns03, dat1$res_cns04r,
                dat1$res_cns05r, dat1$res_cns06,
                dat1$res_cns08, dat1$res_cns09r,
                dat1$res_ext01, dat1$res_ext02r,
                dat1$res_ext03, dat1$res_ext04,
                dat1$res_ext05r, dat1$res_ext06,
                dat1$res_ext07r, dat1$res_neu01,
                dat1$res_neu02r, dat1$res_neu04,
                dat1$res_neu06, dat1$res_neu07r,
                dat1$res_neu08, dat1$res_opn02,
                dat1$res_opn03, dat1$res_opn05,
                dat1$res_opn06, dat1$res_opn07r,
                dat1$res_opn08, dat1$res_opn09r,
                dat1$res_opn10)
  cols_dat2 <- c("id","cnt","sta","ara","relig",
                 "res_agr01r", "res_agr02",
                 "res_agr03r", "res_agr04", 
                 "res_agr05", "res_agr06r",
                 "res_agr07", "res_cns02r",
                 "res_cns03", "res_cns04r",
                 "res_cns05r", "res_cns06",
                 "res_cns08", "res_cns09r",
                 "res_ext01", "res_ext02r",
                 "res_ext03", "res_ext04",
                 "res_ext05r", "res_ext06",
                 "res_ext07r", "res_neu01",
                 "res_neu02r", "res_neu04",
                 "res_neu06", "res_neu07r",
                 "res_neu08", "res_opn02",
                 "res_opn03", "res_opn05",
                 "res_opn06", "res_opn07r",
                 "res_opn08", "res_opn09r",
                 "res_opn10")
  colnames(dat2) <- cols_dat2
  
  dat3 <- rbind(dat3, dat2)
  
}

dat3$zres_agr01r <- scale(dat3$res_agr01r)
dat3$zres_agr02 <- scale(dat3$res_agr02)
dat3$zres_agr03r <- scale(dat3$res_agr03r)
dat3$zres_agr04 <- scale(dat3$res_agr04)
dat3$zres_agr05 <- scale(dat3$res_agr05)
dat3$zres_agr06r <- scale(dat3$res_agr06r)
dat3$zres_agr07 <- scale(dat3$res_agr07)
dat3$zres_cns02r <- scale(dat3$res_cns02r)
dat3$zres_cns03 <- scale(dat3$res_cns03)
dat3$zres_cns04r <- scale(dat3$res_cns04r)
dat3$zres_cns05r <- scale(dat3$res_cns05r)
dat3$zres_cns06 <- scale(dat3$res_cns06)
dat3$zres_cns08 <- scale(dat3$res_cns08)
dat3$zres_cns09r <- scale(dat3$res_cns09r)
dat3$zres_ext01 <- scale(dat3$res_ext01)
dat3$zres_ext02r <- scale(dat3$res_ext02r)
dat3$zres_ext03 <- scale(dat3$res_ext03)
dat3$zres_ext04 <- scale(dat3$res_ext04)
dat3$zres_ext05r <- scale(dat3$res_ext05r)
dat3$zres_ext06 <- scale(dat3$res_ext06)
dat3$zres_ext07r <- scale(dat3$res_ext07r)
dat3$zres_neu01 <- scale(dat3$res_neu01)
dat3$zres_neu02r <- scale(dat3$res_neu02r)
dat3$zres_neu04 <- scale(dat3$res_neu04)
dat3$zres_neu06 <- scale(dat3$res_neu06)
dat3$zres_neu07r <- scale(dat3$res_neu07r)
dat3$zres_neu08 <- scale(dat3$res_neu08)
dat3$zres_opn02 <- scale(dat3$res_opn02)
dat3$zres_opn03 <- scale(dat3$res_opn03)
dat3$zres_opn05 <- scale(dat3$res_opn05)
dat3$zres_opn06 <- scale(dat3$res_opn06)
dat3$zres_opn07r <- scale(dat3$res_opn07r)
dat3$zres_opn08 <- scale(dat3$res_opn08)
dat3$zres_opn09r <- scale(dat3$res_opn09r)
dat3$zres_opn10 <- scale(dat3$res_opn10)

dat_nuances <- dat3

rm(dat1,dat2,dat3,m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,m13,m14,m15,m16,m17,m18,m19,m20,
   m21,m22,m23,m24,m25,m26,m27,m28,m29,m30,m31,m32,m33,m34,m35,cols_dat2,i,num.ara,sample.ara)

#group-mean center and z-standardize level-2 predictor
dat2 <- aggregate(cbind(sta, relig) ~ ara, dat, mean)
dat2$zarelgrp <- scale(dat2$relig - ave(dat2$relig, dat2$sta))
dat2$sta <- NULL
dat2$relig <- NULL
dat_facets <- merge(dat_facets, dat2, by = "ara", all = TRUE)
dat_nuances <- merge(dat_nuances, dat2, by = "ara", all = TRUE)
rm(dat2)

#re-center level-2 predictor for simple slope analysis
dat_facets$zarelmax <- dat_facets$zarelgrp - abs(max(dat_facets$zarelgrp))
dat_facets$zarelmin <- dat_facets$zarelgrp + abs(min(dat_facets$zarelgrp))
dat_nuances$zarelmax <- dat_nuances$zarelgrp - abs(max(dat_nuances$zarelgrp))
dat_nuances$zarelmin <- dat_nuances$zarelgrp + abs(min(dat_nuances$zarelgrp))

#group-mean center and z-standardize level-3 predictor
dat3 <- aggregate(cbind(cnt, relig) ~ sta, dat, mean)
dat3$zsrelgrp <- scale(dat3$relig - ave(dat3$relig, dat3$cnt))
dat3$cnt <- NULL
dat3$relig <- NULL
dat_facets <- merge(dat_facets, dat3, by = "sta", all = TRUE)
dat_nuances <- merge(dat_nuances, dat3, by = "sta", all = TRUE)
rm(dat3)

#re-center level-3 predictor for simple slope analysis
dat_facets$zsrelmax <- dat_facets$zsrelgrp - abs(max(dat_facets$zsrelgrp))
dat_facets$zsrelmin <- dat_facets$zsrelgrp + abs(min(dat_facets$zsrelgrp))
dat_nuances$zsrelmax <- dat_nuances$zsrelgrp - abs(max(dat_nuances$zsrelgrp))
dat_nuances$zsrelmin <- dat_nuances$zsrelgrp + abs(min(dat_nuances$zsrelgrp))

#compute level-4 predictor (z-standardized on Level 4)
dat4 <- aggregate(relig ~ cnt, dat, mean)
dat4$zcrel <- scale(dat4$relig)
dat4$relig <- NULL
dat_facets <- merge(dat_facets, dat4, by = "cnt", all = TRUE)
dat_nuances <- merge(dat_nuances, dat4, by = "cnt", all = TRUE)
rm(dat4,dat)

#re-center level-4 predictor for simple slope analysis
dat_facets$zcrelmax <- dat_facets$zcrel - abs(max(dat_facets$zcrel))
dat_facets$zcrelmin <- dat_facets$zcrel + abs(min(dat_facets$zcrel))
dat_nuances$zcrelmax <- dat_nuances$zcrel - abs(max(dat_nuances$zcrel))
dat_nuances$zcrelmin <- dat_nuances$zcrel + abs(min(dat_nuances$zcrel))

# z-standardize criterion
dat_facets$zprel <- scale(dat_facets$relig)
dat_nuances$zprel <- scale(dat_nuances$relig)

#select variables for facet model in Julia
dat_facets <- subset(dat_facets, select = c(id,cnt,sta,ara,zres_altr:zres_depr,zarelgrp:zprel))

#select variables for nuance model in Julia
dat_nuances <- subset(dat_nuances, select = c(id,cnt,sta,ara,zres_agr01r:zres_opn10,zarelgrp:zprel))


#####Before you continue with this R-Syntax, download and install Julia (https://julialang.org/downloads/)#####


#install JuliaCall
install.packages("JuliaCall")

#load JuliaCall
library(JuliaCall)

#start Julia
julia <- julia_setup() 

#set working directory to the Julia folder indicated in julia_setup (e.g., "C:/AppData/Local/JULIA-~1.1/bin")
setwd("C:/AppData/Local/JULIA-~1.1/bin")

#install Julia packages
julia_install_package("MixedModels")
julia_install_package("DataFrames")
julia_install_package("StatsBase")

#load Julia packages
julia_library("MixedModels")
julia_library("DataFrames")
julia_library("StatsBase")

#conduct facet models in Julia
dat_facets$cnt <- as.factor(dat_facets$cnt)
dat_facets$sta <- as.factor(dat_facets$sta)
dat_facets$ara <- as.factor(dat_facets$ara)
julia_assign("dat_facets", dat_facets)

julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelgrp + zres_altr * zsrelgrp + zres_altr * zcrel
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_altr <- julia_eval("results_study3_altr = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelgrp + zres_comp * zsrelgrp + zres_comp * zcrel
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_comp <- julia_eval("results_study3_comp = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelgrp + zres_orde * zsrelgrp + zres_orde * zcrel
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_orde <- julia_eval("results_study3_orde = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelgrp + zres_disc * zsrelgrp + zres_disc * zcrel
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_disc <- julia_eval("results_study3_disc = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelgrp + zres_asse * zsrelgrp + zres_asse * zcrel
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_asse <- julia_eval("results_study3_asse = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelgrp + zres_acti * zsrelgrp + zres_acti * zcrel
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_acti <- julia_eval("results_study3_acti = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelgrp + zres_idea * zsrelgrp + zres_idea * zcrel
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_idea <- julia_eval("results_study3_idea = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelgrp + zres_aest * zsrelgrp + zres_aest * zcrel
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_aest <- julia_eval("results_study3_aest = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelgrp + zres_depr * zsrelgrp + zres_depr * zcrel
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_depr <- julia_eval("results_study3_depr = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelgrp + zres_anxi * zsrelgrp + zres_anxi * zcrel
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_anxi <- julia_eval("results_study3_anxi = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious countries
julia_eval("fm1a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelgrp + zres_altr * zsrelgrp + zres_altr * zcrelmax
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_altr_cmax <- julia_eval("results_study3_altr_cmax = rename!(DataFrame([(coeftable(fm1a).rownms) (round.(fixef(fm1a, false),digits=5)) (round.(((fixef(fm1a, false))-1.96*(stderror(fm1a))),digits=5)) (round.(((fixef(fm1a, false))+1.96*(stderror(fm1a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelgrp + zres_comp * zsrelgrp + zres_comp * zcrelmax
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_comp_cmax <- julia_eval("results_study3_comp_cmax = rename!(DataFrame([(coeftable(fm2a).rownms) (round.(fixef(fm2a, false),digits=5)) (round.(((fixef(fm2a, false))-1.96*(stderror(fm2a))),digits=5)) (round.(((fixef(fm2a, false))+1.96*(stderror(fm2a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelgrp + zres_orde * zsrelgrp + zres_orde * zcrelmax
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_orde_cmax <- julia_eval("results_study3_orde_cmax = rename!(DataFrame([(coeftable(fm3a).rownms) (round.(fixef(fm3a, false),digits=5)) (round.(((fixef(fm3a, false))-1.96*(stderror(fm3a))),digits=5)) (round.(((fixef(fm3a, false))+1.96*(stderror(fm3a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelgrp + zres_disc * zsrelgrp + zres_disc * zcrelmax
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_disc_cmax <- julia_eval("results_study3_disc_cmax = rename!(DataFrame([(coeftable(fm4a).rownms) (round.(fixef(fm4a, false),digits=5)) (round.(((fixef(fm4a, false))-1.96*(stderror(fm4a))),digits=5)) (round.(((fixef(fm4a, false))+1.96*(stderror(fm4a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelgrp + zres_asse * zsrelgrp + zres_asse * zcrelmax
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_asse_cmax <- julia_eval("results_study3_asse_cmax = rename!(DataFrame([(coeftable(fm5a).rownms) (round.(fixef(fm5a, false),digits=5)) (round.(((fixef(fm5a, false))-1.96*(stderror(fm5a))),digits=5)) (round.(((fixef(fm5a, false))+1.96*(stderror(fm5a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelgrp + zres_acti * zsrelgrp + zres_acti * zcrelmax
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_acti_cmax <- julia_eval("results_study3_acti_cmax = rename!(DataFrame([(coeftable(fm6a).rownms) (round.(fixef(fm6a, false),digits=5)) (round.(((fixef(fm6a, false))-1.96*(stderror(fm6a))),digits=5)) (round.(((fixef(fm6a, false))+1.96*(stderror(fm6a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelgrp + zres_idea * zsrelgrp + zres_idea * zcrelmax
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_idea_cmax <- julia_eval("results_study3_idea_cmax = rename!(DataFrame([(coeftable(fm7a).rownms) (round.(fixef(fm7a, false),digits=5)) (round.(((fixef(fm7a, false))-1.96*(stderror(fm7a))),digits=5)) (round.(((fixef(fm7a, false))+1.96*(stderror(fm7a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelgrp + zres_aest * zsrelgrp + zres_aest * zcrelmax
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_aest_cmax <- julia_eval("results_study3_aest_cmax = rename!(DataFrame([(coeftable(fm8a).rownms) (round.(fixef(fm8a, false),digits=5)) (round.(((fixef(fm8a, false))-1.96*(stderror(fm8a))),digits=5)) (round.(((fixef(fm8a, false))+1.96*(stderror(fm8a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelgrp + zres_depr * zsrelgrp + zres_depr * zcrelmax
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_depr_cmax <- julia_eval("results_study3_depr_cmax = rename!(DataFrame([(coeftable(fm9a).rownms) (round.(fixef(fm9a, false),digits=5)) (round.(((fixef(fm9a, false))-1.96*(stderror(fm9a))),digits=5)) (round.(((fixef(fm9a, false))+1.96*(stderror(fm9a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10a = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelgrp + zres_anxi * zsrelgrp + zres_anxi * zcrelmax
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_anxi_cmax <- julia_eval("results_study3_anxi_cmax = rename!(DataFrame([(coeftable(fm10a).rownms) (round.(fixef(fm10a, false),digits=5)) (round.(((fixef(fm10a, false))-1.96*(stderror(fm10a))),digits=5)) (round.(((fixef(fm10a, false))+1.96*(stderror(fm10a))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious states in most religious countries
julia_eval("fm1b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelgrp + zres_altr * zsrelmax + zres_altr * zcrelmax
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_altr_smax <- julia_eval("results_study3_altr_smax = rename!(DataFrame([(coeftable(fm1b).rownms) (round.(fixef(fm1b, false),digits=5)) (round.(((fixef(fm1b, false))-1.96*(stderror(fm1b))),digits=5)) (round.(((fixef(fm1b, false))+1.96*(stderror(fm1b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelgrp + zres_comp * zsrelmax + zres_comp * zcrelmax
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_comp_smax <- julia_eval("results_study3_comp_smax = rename!(DataFrame([(coeftable(fm2b).rownms) (round.(fixef(fm2b, false),digits=5)) (round.(((fixef(fm2b, false))-1.96*(stderror(fm2b))),digits=5)) (round.(((fixef(fm2b, false))+1.96*(stderror(fm2b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelgrp + zres_orde * zsrelmax + zres_orde * zcrelmax
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_orde_smax <- julia_eval("results_study3_orde_smax = rename!(DataFrame([(coeftable(fm3b).rownms) (round.(fixef(fm3b, false),digits=5)) (round.(((fixef(fm3b, false))-1.96*(stderror(fm3b))),digits=5)) (round.(((fixef(fm3b, false))+1.96*(stderror(fm3b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelgrp + zres_disc * zsrelmax + zres_disc * zcrelmax
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_disc_smax <- julia_eval("results_study3_disc_smax = rename!(DataFrame([(coeftable(fm4b).rownms) (round.(fixef(fm4b, false),digits=5)) (round.(((fixef(fm4b, false))-1.96*(stderror(fm4b))),digits=5)) (round.(((fixef(fm4b, false))+1.96*(stderror(fm4b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelgrp + zres_asse * zsrelmax + zres_asse * zcrelmax
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_asse_smax <- julia_eval("results_study3_asse_smax = rename!(DataFrame([(coeftable(fm5b).rownms) (round.(fixef(fm5b, false),digits=5)) (round.(((fixef(fm5b, false))-1.96*(stderror(fm5b))),digits=5)) (round.(((fixef(fm5b, false))+1.96*(stderror(fm5b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelgrp + zres_acti * zsrelmax + zres_acti * zcrelmax
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_acti_smax <- julia_eval("results_study3_acti_smax = rename!(DataFrame([(coeftable(fm6b).rownms) (round.(fixef(fm6b, false),digits=5)) (round.(((fixef(fm6b, false))-1.96*(stderror(fm6b))),digits=5)) (round.(((fixef(fm6b, false))+1.96*(stderror(fm6b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelgrp + zres_idea * zsrelmax + zres_idea * zcrelmax
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_idea_smax <- julia_eval("results_study3_idea_smax = rename!(DataFrame([(coeftable(fm7b).rownms) (round.(fixef(fm7b, false),digits=5)) (round.(((fixef(fm7b, false))-1.96*(stderror(fm7b))),digits=5)) (round.(((fixef(fm7b, false))+1.96*(stderror(fm7b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelgrp + zres_aest * zsrelmax + zres_aest * zcrelmax
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_aest_smax <- julia_eval("results_study3_aest_smax = rename!(DataFrame([(coeftable(fm8b).rownms) (round.(fixef(fm8b, false),digits=5)) (round.(((fixef(fm8b, false))-1.96*(stderror(fm8b))),digits=5)) (round.(((fixef(fm8b, false))+1.96*(stderror(fm8b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelgrp + zres_depr * zsrelmax + zres_depr * zcrelmax
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_depr_smax <- julia_eval("results_study3_depr_smax = rename!(DataFrame([(coeftable(fm9b).rownms) (round.(fixef(fm9b, false),digits=5)) (round.(((fixef(fm9b, false))-1.96*(stderror(fm9b))),digits=5)) (round.(((fixef(fm9b, false))+1.96*(stderror(fm9b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10b = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelgrp + zres_anxi * zsrelmax + zres_anxi * zcrelmax
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_anxi_smax <- julia_eval("results_study3_anxi_smax = rename!(DataFrame([(coeftable(fm10b).rownms) (round.(fixef(fm10b, false),digits=5)) (round.(((fixef(fm10b, false))-1.96*(stderror(fm10b))),digits=5)) (round.(((fixef(fm10b, false))+1.96*(stderror(fm10b))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious cities in most religious states in most religious countries
julia_eval("fm1c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelmax + zres_altr * zsrelmax + zres_altr * zcrelmax
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_altr_amax <- julia_eval("results_study3_altr_amax = rename!(DataFrame([(coeftable(fm1c).rownms) (round.(fixef(fm1c, false),digits=5)) (round.(((fixef(fm1c, false))-1.96*(stderror(fm1c))),digits=5)) (round.(((fixef(fm1c, false))+1.96*(stderror(fm1c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelmax + zres_comp * zsrelmax + zres_comp * zcrelmax
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_comp_amax <- julia_eval("results_study3_comp_amax = rename!(DataFrame([(coeftable(fm2c).rownms) (round.(fixef(fm2c, false),digits=5)) (round.(((fixef(fm2c, false))-1.96*(stderror(fm2c))),digits=5)) (round.(((fixef(fm2c, false))+1.96*(stderror(fm2c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelmax + zres_orde * zsrelmax + zres_orde * zcrelmax
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_orde_amax <- julia_eval("results_study3_orde_amax = rename!(DataFrame([(coeftable(fm3c).rownms) (round.(fixef(fm3c, false),digits=5)) (round.(((fixef(fm3c, false))-1.96*(stderror(fm3c))),digits=5)) (round.(((fixef(fm3c, false))+1.96*(stderror(fm3c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelmax + zres_disc * zsrelmax + zres_disc * zcrelmax
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_disc_amax <- julia_eval("results_study3_disc_amax = rename!(DataFrame([(coeftable(fm4c).rownms) (round.(fixef(fm4c, false),digits=5)) (round.(((fixef(fm4c, false))-1.96*(stderror(fm4c))),digits=5)) (round.(((fixef(fm4c, false))+1.96*(stderror(fm4c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelmax + zres_asse * zsrelmax + zres_asse * zcrelmax
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_asse_amax <- julia_eval("results_study3_asse_amax = rename!(DataFrame([(coeftable(fm5c).rownms) (round.(fixef(fm5c, false),digits=5)) (round.(((fixef(fm5c, false))-1.96*(stderror(fm5c))),digits=5)) (round.(((fixef(fm5c, false))+1.96*(stderror(fm5c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelmax + zres_acti * zsrelmax + zres_acti * zcrelmax
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_acti_amax <- julia_eval("results_study3_acti_amax = rename!(DataFrame([(coeftable(fm6c).rownms) (round.(fixef(fm6c, false),digits=5)) (round.(((fixef(fm6c, false))-1.96*(stderror(fm6c))),digits=5)) (round.(((fixef(fm6c, false))+1.96*(stderror(fm6c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelmax + zres_idea * zsrelmax + zres_idea * zcrelmax
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_idea_amax <- julia_eval("results_study3_idea_amax = rename!(DataFrame([(coeftable(fm7c).rownms) (round.(fixef(fm7c, false),digits=5)) (round.(((fixef(fm7c, false))-1.96*(stderror(fm7c))),digits=5)) (round.(((fixef(fm7c, false))+1.96*(stderror(fm7c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelmax + zres_aest * zsrelmax + zres_aest * zcrelmax
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_aest_amax <- julia_eval("results_study3_aest_amax = rename!(DataFrame([(coeftable(fm8c).rownms) (round.(fixef(fm8c, false),digits=5)) (round.(((fixef(fm8c, false))-1.96*(stderror(fm8c))),digits=5)) (round.(((fixef(fm8c, false))+1.96*(stderror(fm8c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelmax + zres_depr * zsrelmax + zres_depr * zcrelmax
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_depr_amax <- julia_eval("results_study3_depr_amax = rename!(DataFrame([(coeftable(fm9c).rownms) (round.(fixef(fm9c, false),digits=5)) (round.(((fixef(fm9c, false))-1.96*(stderror(fm9c))),digits=5)) (round.(((fixef(fm9c, false))+1.96*(stderror(fm9c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10c = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelmax + zres_anxi * zsrelmax + zres_anxi * zcrelmax
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_facets)")
results_study3_anxi_amax <- julia_eval("results_study3_anxi_amax = rename!(DataFrame([(coeftable(fm10c).rownms) (round.(fixef(fm10c, false),digits=5)) (round.(((fixef(fm10c, false))-1.96*(stderror(fm10c))),digits=5)) (round.(((fixef(fm10c, false))+1.96*(stderror(fm10c))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious countries
julia_eval("fm1d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelgrp + zres_altr * zsrelgrp + zres_altr * zcrelmin
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_altr_cmin <- julia_eval("results_study3_altr_cmin = rename!(DataFrame([(coeftable(fm1d).rownms) (round.(fixef(fm1d, false),digits=5)) (round.(((fixef(fm1d, false))-1.96*(stderror(fm1d))),digits=5)) (round.(((fixef(fm1d, false))+1.96*(stderror(fm1d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelgrp + zres_comp * zsrelgrp + zres_comp * zcrelmin
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_comp_cmin <- julia_eval("results_study3_comp_cmin = rename!(DataFrame([(coeftable(fm2d).rownms) (round.(fixef(fm2d, false),digits=5)) (round.(((fixef(fm2d, false))-1.96*(stderror(fm2d))),digits=5)) (round.(((fixef(fm2d, false))+1.96*(stderror(fm2d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelgrp + zres_orde * zsrelgrp + zres_orde * zcrelmin
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_orde_cmin <- julia_eval("results_study3_orde_cmin = rename!(DataFrame([(coeftable(fm3d).rownms) (round.(fixef(fm3d, false),digits=5)) (round.(((fixef(fm3d, false))-1.96*(stderror(fm3d))),digits=5)) (round.(((fixef(fm3d, false))+1.96*(stderror(fm3d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelgrp + zres_disc * zsrelgrp + zres_disc * zcrelmin
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_disc_cmin <- julia_eval("results_study3_disc_cmin = rename!(DataFrame([(coeftable(fm4d).rownms) (round.(fixef(fm4d, false),digits=5)) (round.(((fixef(fm4d, false))-1.96*(stderror(fm4d))),digits=5)) (round.(((fixef(fm4d, false))+1.96*(stderror(fm4d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelgrp + zres_asse * zsrelgrp + zres_asse * zcrelmin
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_asse_cmin <- julia_eval("results_study3_asse_cmin = rename!(DataFrame([(coeftable(fm5d).rownms) (round.(fixef(fm5d, false),digits=5)) (round.(((fixef(fm5d, false))-1.96*(stderror(fm5d))),digits=5)) (round.(((fixef(fm5d, false))+1.96*(stderror(fm5d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelgrp + zres_acti * zsrelgrp + zres_acti * zcrelmin
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_acti_cmin <- julia_eval("results_study3_acti_cmin = rename!(DataFrame([(coeftable(fm6d).rownms) (round.(fixef(fm6d, false),digits=5)) (round.(((fixef(fm6d, false))-1.96*(stderror(fm6d))),digits=5)) (round.(((fixef(fm6d, false))+1.96*(stderror(fm6d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelgrp + zres_idea * zsrelgrp + zres_idea * zcrelmin
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_idea_cmin <- julia_eval("results_study3_idea_cmin = rename!(DataFrame([(coeftable(fm7d).rownms) (round.(fixef(fm7d, false),digits=5)) (round.(((fixef(fm7d, false))-1.96*(stderror(fm7d))),digits=5)) (round.(((fixef(fm7d, false))+1.96*(stderror(fm7d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###In order for model fm8d to converge without errors, we omitted the random slope for zsrelgrp.###
julia_eval("fm8d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelgrp + zres_aest * zsrelgrp + zres_aest * zcrelmin
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelgrp) | cnt)), dat_facets)")
results_study3_aest_cmin <- julia_eval("results_study3_aest_cmin = rename!(DataFrame([(coeftable(fm8d).rownms) (round.(fixef(fm8d, false),digits=5)) (round.(((fixef(fm8d, false))-1.96*(stderror(fm8d))),digits=5)) (round.(((fixef(fm8d, false))+1.96*(stderror(fm8d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelgrp + zres_depr * zsrelgrp + zres_depr * zcrelmin
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_depr_cmin <- julia_eval("results_study3_depr_cmin = rename!(DataFrame([(coeftable(fm9d).rownms) (round.(fixef(fm9d, false),digits=5)) (round.(((fixef(fm9d, false))-1.96*(stderror(fm9d))),digits=5)) (round.(((fixef(fm9d, false))+1.96*(stderror(fm9d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10d = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelgrp + zres_anxi * zsrelgrp + zres_anxi * zcrelmin
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_facets)")
results_study3_anxi_cmin <- julia_eval("results_study3_anxi_cmin = rename!(DataFrame([(coeftable(fm10d).rownms) (round.(fixef(fm10d, false),digits=5)) (round.(((fixef(fm10d, false))-1.96*(stderror(fm10d))),digits=5)) (round.(((fixef(fm10d, false))+1.96*(stderror(fm10d))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious states in least religious countries
julia_eval("fm1e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelgrp + zres_altr * zsrelmin + zres_altr * zcrelmin
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_altr_smin <- julia_eval("results_study3_altr_smin = rename!(DataFrame([(coeftable(fm1e).rownms) (round.(fixef(fm1e, false),digits=5)) (round.(((fixef(fm1e, false))-1.96*(stderror(fm1e))),digits=5)) (round.(((fixef(fm1e, false))+1.96*(stderror(fm1e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelgrp + zres_comp * zsrelmin + zres_comp * zcrelmin
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_comp_smin <- julia_eval("results_study3_comp_smin = rename!(DataFrame([(coeftable(fm2e).rownms) (round.(fixef(fm2e, false),digits=5)) (round.(((fixef(fm2e, false))-1.96*(stderror(fm2e))),digits=5)) (round.(((fixef(fm2e, false))+1.96*(stderror(fm2e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelgrp + zres_orde * zsrelmin + zres_orde * zcrelmin
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_orde_smin <- julia_eval("results_study3_orde_smin = rename!(DataFrame([(coeftable(fm3e).rownms) (round.(fixef(fm3e, false),digits=5)) (round.(((fixef(fm3e, false))-1.96*(stderror(fm3e))),digits=5)) (round.(((fixef(fm3e, false))+1.96*(stderror(fm3e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelgrp + zres_disc * zsrelmin + zres_disc * zcrelmin
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_disc_smin <- julia_eval("results_study3_disc_smin = rename!(DataFrame([(coeftable(fm4e).rownms) (round.(fixef(fm4e, false),digits=5)) (round.(((fixef(fm4e, false))-1.96*(stderror(fm4e))),digits=5)) (round.(((fixef(fm4e, false))+1.96*(stderror(fm4e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelgrp + zres_asse * zsrelmin + zres_asse * zcrelmin
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_asse_smin <- julia_eval("results_study3_asse_smin = rename!(DataFrame([(coeftable(fm5e).rownms) (round.(fixef(fm5e, false),digits=5)) (round.(((fixef(fm5e, false))-1.96*(stderror(fm5e))),digits=5)) (round.(((fixef(fm5e, false))+1.96*(stderror(fm5e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelgrp + zres_acti * zsrelmin + zres_acti * zcrelmin
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_acti_smin <- julia_eval("results_study3_acti_smin = rename!(DataFrame([(coeftable(fm6e).rownms) (round.(fixef(fm6e, false),digits=5)) (round.(((fixef(fm6e, false))-1.96*(stderror(fm6e))),digits=5)) (round.(((fixef(fm6e, false))+1.96*(stderror(fm6e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelgrp + zres_idea * zsrelmin + zres_idea * zcrelmin
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_idea_smin <- julia_eval("results_study3_idea_smin = rename!(DataFrame([(coeftable(fm7e).rownms) (round.(fixef(fm7e, false),digits=5)) (round.(((fixef(fm7e, false))-1.96*(stderror(fm7e))),digits=5)) (round.(((fixef(fm7e, false))+1.96*(stderror(fm7e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelgrp + zres_aest * zsrelmin + zres_aest * zcrelmin
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_aest_smin <- julia_eval("results_study3_aest_smin = rename!(DataFrame([(coeftable(fm8e).rownms) (round.(fixef(fm8e, false),digits=5)) (round.(((fixef(fm8e, false))-1.96*(stderror(fm8e))),digits=5)) (round.(((fixef(fm8e, false))+1.96*(stderror(fm8e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelgrp + zres_depr * zsrelmin + zres_depr * zcrelmin
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_depr_smin <- julia_eval("results_study3_depr_smin = rename!(DataFrame([(coeftable(fm9e).rownms) (round.(fixef(fm9e, false),digits=5)) (round.(((fixef(fm9e, false))-1.96*(stderror(fm9e))),digits=5)) (round.(((fixef(fm9e, false))+1.96*(stderror(fm9e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10e = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelgrp + zres_anxi * zsrelmin + zres_anxi * zcrelmin
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_anxi_smin <- julia_eval("results_study3_anxi_smin = rename!(DataFrame([(coeftable(fm10e).rownms) (round.(fixef(fm10e, false),digits=5)) (round.(((fixef(fm10e, false))-1.96*(stderror(fm10e))),digits=5)) (round.(((fixef(fm10e, false))+1.96*(stderror(fm10e))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious cities in least religious states in least religious countries
julia_eval("fm1f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_altr * zarelmin + zres_altr * zsrelmin + zres_altr * zcrelmin
+ (1 | ara) + ((0 + zres_altr) | ara) + (1 | sta) + ((0 + zres_altr) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_altr) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_altr_amin <- julia_eval("results_study3_altr_amin = rename!(DataFrame([(coeftable(fm1f).rownms) (round.(fixef(fm1f, false),digits=5)) (round.(((fixef(fm1f, false))-1.96*(stderror(fm1f))),digits=5)) (round.(((fixef(fm1f, false))+1.96*(stderror(fm1f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm2f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_comp * zarelmin + zres_comp * zsrelmin + zres_comp * zcrelmin
+ (1 | ara) + ((0 + zres_comp) | ara) + (1 | sta) + ((0 + zres_comp) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_comp) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_comp_amin <- julia_eval("results_study3_comp_amin = rename!(DataFrame([(coeftable(fm2f).rownms) (round.(fixef(fm2f, false),digits=5)) (round.(((fixef(fm2f, false))-1.96*(stderror(fm2f))),digits=5)) (round.(((fixef(fm2f, false))+1.96*(stderror(fm2f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_orde * zarelmin + zres_orde * zsrelmin + zres_orde * zcrelmin
+ (1 | ara) + ((0 + zres_orde) | ara) + (1 | sta) + ((0 + zres_orde) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_orde) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_orde_amin <- julia_eval("results_study3_orde_amin = rename!(DataFrame([(coeftable(fm3f).rownms) (round.(fixef(fm3f, false),digits=5)) (round.(((fixef(fm3f, false))-1.96*(stderror(fm3f))),digits=5)) (round.(((fixef(fm3f, false))+1.96*(stderror(fm3f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_disc * zarelmin + zres_disc * zsrelmin + zres_disc * zcrelmin
+ (1 | ara) + ((0 + zres_disc) | ara) + (1 | sta) + ((0 + zres_disc) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_disc) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_disc_amin <- julia_eval("results_study3_disc_amin = rename!(DataFrame([(coeftable(fm4f).rownms) (round.(fixef(fm4f, false),digits=5)) (round.(((fixef(fm4f, false))-1.96*(stderror(fm4f))),digits=5)) (round.(((fixef(fm4f, false))+1.96*(stderror(fm4f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_asse * zarelmin + zres_asse * zsrelmin + zres_asse * zcrelmin
+ (1 | ara) + ((0 + zres_asse) | ara) + (1 | sta) + ((0 + zres_asse) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_asse) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_asse_amin <- julia_eval("results_study3_asse_amin = rename!(DataFrame([(coeftable(fm5f).rownms) (round.(fixef(fm5f, false),digits=5)) (round.(((fixef(fm5f, false))-1.96*(stderror(fm5f))),digits=5)) (round.(((fixef(fm5f, false))+1.96*(stderror(fm5f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_acti * zarelmin + zres_acti * zsrelmin + zres_acti * zcrelmin
+ (1 | ara) + ((0 + zres_acti) | ara) + (1 | sta) + ((0 + zres_acti) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_acti) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_acti_amin <- julia_eval("results_study3_acti_amin = rename!(DataFrame([(coeftable(fm6f).rownms) (round.(fixef(fm6f, false),digits=5)) (round.(((fixef(fm6f, false))-1.96*(stderror(fm6f))),digits=5)) (round.(((fixef(fm6f, false))+1.96*(stderror(fm6f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_idea * zarelmin + zres_idea * zsrelmin + zres_idea * zcrelmin
+ (1 | ara) + ((0 + zres_idea) | ara) + (1 | sta) + ((0 + zres_idea) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_idea) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_idea_amin <- julia_eval("results_study3_idea_amin = rename!(DataFrame([(coeftable(fm7f).rownms) (round.(fixef(fm7f, false),digits=5)) (round.(((fixef(fm7f, false))-1.96*(stderror(fm7f))),digits=5)) (round.(((fixef(fm7f, false))+1.96*(stderror(fm7f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm8f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_aest * zarelmin + zres_aest * zsrelmin + zres_aest * zcrelmin
+ (1 | ara) + ((0 + zres_aest) | ara) + (1 | sta) + ((0 + zres_aest) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_aest) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_aest_amin <- julia_eval("results_study3_aest_amin = rename!(DataFrame([(coeftable(fm8f).rownms) (round.(fixef(fm8f, false),digits=5)) (round.(((fixef(fm8f, false))-1.96*(stderror(fm8f))),digits=5)) (round.(((fixef(fm8f, false))+1.96*(stderror(fm8f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm9f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_depr * zarelmin + zres_depr * zsrelmin + zres_depr * zcrelmin
+ (1 | ara) + ((0 + zres_depr) | ara) + (1 | sta) + ((0 + zres_depr) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_depr) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_depr_amin <- julia_eval("results_study3_depr_amin = rename!(DataFrame([(coeftable(fm9f).rownms) (round.(fixef(fm9f, false),digits=5)) (round.(((fixef(fm9f, false))-1.96*(stderror(fm9f))),digits=5)) (round.(((fixef(fm9f, false))+1.96*(stderror(fm9f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10f = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_anxi * zarelmin + zres_anxi * zsrelmin + zres_anxi * zcrelmin
+ (1 | ara) + ((0 + zres_anxi) | ara) + (1 | sta) + ((0 + zres_anxi) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_anxi) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_facets)")
results_study3_anxi_amin <- julia_eval("results_study3_anxi_amin = rename!(DataFrame([(coeftable(fm10f).rownms) (round.(fixef(fm10f, false),digits=5)) (round.(((fixef(fm10f, false))-1.96*(stderror(fm10f))),digits=5)) (round.(((fixef(fm10f, false))+1.96*(stderror(fm10f))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")


#conduct nuance models in Julia
dat_nuances$cnt <- as.factor(dat_nuances$cnt)
dat_nuances$sta <- as.factor(dat_nuances$sta)
dat_nuances$ara <- as.factor(dat_nuances$ara)
julia_assign("dat_nuances", dat_nuances)

##A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelgrp + zres_agr02 * zsrelgrp + zres_agr02 * zcrel
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr02 <- julia_eval("results_study3_agr02 = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelgrp + zres_agr05 * zsrelgrp + zres_agr05 * zcrel
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr05 <- julia_eval("results_study3_agr05 = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelgrp + zres_agr06r * zsrelgrp + zres_agr06r * zcrel
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr06r <- julia_eval("results_study3_agr06r = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelgrp + zres_agr07 * zsrelgrp + zres_agr07 * zcrel
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr07 <- julia_eval("results_study3_agr07 = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelgrp + zres_agr01r * zsrelgrp + zres_agr01r * zcrel
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr01r <- julia_eval("results_study3_agr01r = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelgrp + zres_agr03r * zsrelgrp + zres_agr03r * zcrel
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr03r <- julia_eval("results_study3_agr03r = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelgrp + zres_agr04 * zsrelgrp + zres_agr04 * zcrel
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr04 <- julia_eval("results_study3_agr04 = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelgrp + zres_cns02r * zsrelgrp + zres_cns02r * zcrel
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns02r <- julia_eval("results_study3_cns02r = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelgrp + zres_cns04r * zsrelgrp + zres_cns04r * zcrel
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns04r <- julia_eval("results_study3_cns04r = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelgrp + zres_cns03 * zsrelgrp + zres_cns03 * zcrel
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns03 <- julia_eval("results_study3_cns03 = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelgrp + zres_cns05r * zsrelgrp + zres_cns05r * zcrel
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns05r <- julia_eval("results_study3_cns05r = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelgrp + zres_cns06 * zsrelgrp + zres_cns06 * zcrel
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns06 <- julia_eval("results_study3_cns06 = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelgrp + zres_cns08 * zsrelgrp + zres_cns08 * zcrel
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns08 <- julia_eval("results_study3_cns08 = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelgrp + zres_cns09r * zsrelgrp + zres_cns09r * zcrel
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns09r <- julia_eval("results_study3_cns09r = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelgrp + zres_ext01 * zsrelgrp + zres_ext01 * zcrel
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext01 <- julia_eval("results_study3_ext01 = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelgrp + zres_ext02r * zsrelgrp + zres_ext02r * zcrel
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext02r <- julia_eval("results_study3_ext02r = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelgrp + zres_ext05r * zsrelgrp + zres_ext05r * zcrel
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext05r <- julia_eval("results_study3_ext05r = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelgrp + zres_ext06 * zsrelgrp + zres_ext06 * zcrel
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext06 <- julia_eval("results_study3_ext06 = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelgrp + zres_ext07r * zsrelgrp + zres_ext07r * zcrel
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext07r <- julia_eval("results_study3_ext07r = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelgrp + zres_ext03 * zsrelgrp + zres_ext03 * zcrel
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext03 <- julia_eval("results_study3_ext03 = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelgrp + zres_ext04 * zsrelgrp + zres_ext04 * zcrel
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext04 <- julia_eval("results_study3_ext04 = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelgrp + zres_opn02 * zsrelgrp + zres_opn02 * zcrel
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn02 <- julia_eval("results_study3_opn02 = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelgrp + zres_opn03 * zsrelgrp + zres_opn03 * zcrel
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn03 <- julia_eval("results_study3_opn03 = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelgrp + zres_opn05 * zsrelgrp + zres_opn05 * zcrel
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn05 <- julia_eval("results_study3_opn05 = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelgrp + zres_opn07r * zsrelgrp + zres_opn07r * zcrel
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn07r <- julia_eval("results_study3_opn07r = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelgrp + zres_opn08 * zsrelgrp + zres_opn08 * zcrel
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn08 <- julia_eval("results_study3_opn08 = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelgrp + zres_opn06 * zsrelgrp + zres_opn06 * zcrel
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn06 <- julia_eval("results_study3_opn06 = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelgrp + zres_opn09r * zsrelgrp + zres_opn09r * zcrel
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn09r <- julia_eval("results_study3_opn09r = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelgrp + zres_opn10 * zsrelgrp + zres_opn10 * zcrel
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn10 <- julia_eval("results_study3_opn10 = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelgrp + zres_neu01 * zsrelgrp + zres_neu01 * zcrel
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu01 <- julia_eval("results_study3_neu01 = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelgrp + zres_neu06 * zsrelgrp + zres_neu06 * zcrel
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu06 <- julia_eval("results_study3_neu06 = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelgrp + zres_neu02r * zsrelgrp + zres_neu02r * zcrel
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu02r <- julia_eval("results_study3_neu02r = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelgrp + zres_neu04 * zsrelgrp + zres_neu04 * zcrel
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu04 <- julia_eval("results_study3_neu04 = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelgrp + zres_neu07r * zsrelgrp + zres_neu07r * zcrel
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu07r <- julia_eval("results_study3_neu07r = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelgrp + zres_neu08 * zsrelgrp + zres_neu08 * zcrel
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu08 <- julia_eval("results_study3_neu08 = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelgrp + zres_agr02 * zsrelgrp + zres_agr02 * zcrelmax
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr02_cmax <- julia_eval("results_study3_agr02_cmax = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelgrp + zres_agr05 * zsrelgrp + zres_agr05 * zcrelmax
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr05_cmax <- julia_eval("results_study3_agr05_cmax = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelgrp + zres_agr06r * zsrelgrp + zres_agr06r * zcrelmax
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr06r_cmax <- julia_eval("results_study3_agr06r_cmax = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelgrp + zres_agr07 * zsrelgrp + zres_agr07 * zcrelmax
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr07_cmax <- julia_eval("results_study3_agr07_cmax = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelgrp + zres_agr01r * zsrelgrp + zres_agr01r * zcrelmax
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr01r_cmax <- julia_eval("results_study3_agr01r_cmax = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelgrp + zres_agr03r * zsrelgrp + zres_agr03r * zcrelmax
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr03r_cmax <- julia_eval("results_study3_agr03r_cmax = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelgrp + zres_agr04 * zsrelgrp + zres_agr04 * zcrelmax
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr04_cmax <- julia_eval("results_study3_agr04_cmax = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelgrp + zres_cns02r * zsrelgrp + zres_cns02r * zcrelmax
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns02r_cmax <- julia_eval("results_study3_cns02r_cmax = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelgrp + zres_cns04r * zsrelgrp + zres_cns04r * zcrelmax
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns04r_cmax <- julia_eval("results_study3_cns04r_cmax = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelgrp + zres_cns03 * zsrelgrp + zres_cns03 * zcrelmax
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns03_cmax <- julia_eval("results_study3_cns03_cmax = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelgrp + zres_cns05r * zsrelgrp + zres_cns05r * zcrelmax
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns05r_cmax <- julia_eval("results_study3_cns05r_cmax = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelgrp + zres_cns06 * zsrelgrp + zres_cns06 * zcrelmax
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns06_cmax <- julia_eval("results_study3_cns06_cmax = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelgrp + zres_cns08 * zsrelgrp + zres_cns08 * zcrelmax
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns08_cmax <- julia_eval("results_study3_cns08_cmax = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelgrp + zres_cns09r * zsrelgrp + zres_cns09r * zcrelmax
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns09r_cmax <- julia_eval("results_study3_cns09r_cmax = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelgrp + zres_ext01 * zsrelgrp + zres_ext01 * zcrelmax
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext01_cmax <- julia_eval("results_study3_ext01_cmax = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelgrp + zres_ext02r * zsrelgrp + zres_ext02r * zcrelmax
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext02r_cmax <- julia_eval("results_study3_ext02r_cmax = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelgrp + zres_ext05r * zsrelgrp + zres_ext05r * zcrelmax
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext05r_cmax <- julia_eval("results_study3_ext05r_cmax = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelgrp + zres_ext06 * zsrelgrp + zres_ext06 * zcrelmax
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext06_cmax <- julia_eval("results_study3_ext06_cmax = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelgrp + zres_ext07r * zsrelgrp + zres_ext07r * zcrelmax
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext07r_cmax <- julia_eval("results_study3_ext07r_cmax = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelgrp + zres_ext03 * zsrelgrp + zres_ext03 * zcrelmax
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext03_cmax <- julia_eval("results_study3_ext03_cmax = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelgrp + zres_ext04 * zsrelgrp + zres_ext04 * zcrelmax
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext04_cmax <- julia_eval("results_study3_ext04_cmax = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelgrp + zres_opn02 * zsrelgrp + zres_opn02 * zcrelmax
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn02_cmax <- julia_eval("results_study3_opn02_cmax = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelgrp + zres_opn03 * zsrelgrp + zres_opn03 * zcrelmax
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn03_cmax <- julia_eval("results_study3_opn03_cmax = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelgrp + zres_opn05 * zsrelgrp + zres_opn05 * zcrelmax
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn05_cmax <- julia_eval("results_study3_opn05_cmax = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelgrp + zres_opn07r * zsrelgrp + zres_opn07r * zcrelmax
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn07r_cmax <- julia_eval("results_study3_opn07r_cmax = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelgrp + zres_opn08 * zsrelgrp + zres_opn08 * zcrelmax
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn08_cmax <- julia_eval("results_study3_opn08_cmax = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelgrp + zres_opn06 * zsrelgrp + zres_opn06 * zcrelmax
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn06_cmax <- julia_eval("results_study3_opn06_cmax = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelgrp + zres_opn09r * zsrelgrp + zres_opn09r * zcrelmax
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn09r_cmax <- julia_eval("results_study3_opn09r_cmax = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelgrp + zres_opn10 * zsrelgrp + zres_opn10 * zcrelmax
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn10_cmax <- julia_eval("results_study3_opn10_cmax = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelgrp + zres_neu01 * zsrelgrp + zres_neu01 * zcrelmax
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu01_cmax <- julia_eval("results_study3_neu01_cmax = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelgrp + zres_neu06 * zsrelgrp + zres_neu06 * zcrelmax
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu06_cmax <- julia_eval("results_study3_neu06_cmax = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelgrp + zres_neu02r * zsrelgrp + zres_neu02r * zcrelmax
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu02r_cmax <- julia_eval("results_study3_neu02r_cmax = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelgrp + zres_neu04 * zsrelgrp + zres_neu04 * zcrelmax
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu04_cmax <- julia_eval("results_study3_neu04_cmax = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelgrp + zres_neu07r * zsrelgrp + zres_neu07r * zcrelmax
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu07r_cmax <- julia_eval("results_study3_neu07r_cmax = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelgrp + zres_neu08 * zsrelgrp + zres_neu08 * zcrelmax
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu08_cmax <- julia_eval("results_study3_neu08_cmax = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious states in most religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelgrp + zres_agr02 * zsrelmax + zres_agr02 * zcrelmax
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr02_smax <- julia_eval("results_study3_agr02_smax = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelgrp + zres_agr05 * zsrelmax + zres_agr05 * zcrelmax
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr05_smax <- julia_eval("results_study3_agr05_smax = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelgrp + zres_agr06r * zsrelmax + zres_agr06r * zcrelmax
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr06r_smax <- julia_eval("results_study3_agr06r_smax = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelgrp + zres_agr07 * zsrelmax + zres_agr07 * zcrelmax
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr07_smax <- julia_eval("results_study3_agr07_smax = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelgrp + zres_agr01r * zsrelmax + zres_agr01r * zcrelmax
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr01r_smax <- julia_eval("results_study3_agr01r_smax = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelgrp + zres_agr03r * zsrelmax + zres_agr03r * zcrelmax
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr03r_smax <- julia_eval("results_study3_agr03r_smax = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelgrp + zres_agr04 * zsrelmax + zres_agr04 * zcrelmax
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr04_smax <- julia_eval("results_study3_agr04_smax = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelgrp + zres_cns02r * zsrelmax + zres_cns02r * zcrelmax
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns02r_smax <- julia_eval("results_study3_cns02r_smax = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelgrp + zres_cns04r * zsrelmax + zres_cns04r * zcrelmax
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns04r_smax <- julia_eval("results_study3_cns04r_smax = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelgrp + zres_cns03 * zsrelmax + zres_cns03 * zcrelmax
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns03_smax <- julia_eval("results_study3_cns03_smax = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelgrp + zres_cns05r * zsrelmax + zres_cns05r * zcrelmax
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns05r_smax <- julia_eval("results_study3_cns05r_smax = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelgrp + zres_cns06 * zsrelmax + zres_cns06 * zcrelmax
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns06_smax <- julia_eval("results_study3_cns06_smax = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelgrp + zres_cns08 * zsrelmax + zres_cns08 * zcrelmax
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns08_smax <- julia_eval("results_study3_cns08_smax = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelgrp + zres_cns09r * zsrelmax + zres_cns09r * zcrelmax
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns09r_smax <- julia_eval("results_study3_cns09r_smax = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelgrp + zres_ext01 * zsrelmax + zres_ext01 * zcrelmax
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext01_smax <- julia_eval("results_study3_ext01_smax = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelgrp + zres_ext02r * zsrelmax + zres_ext02r * zcrelmax
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext02r_smax <- julia_eval("results_study3_ext02r_smax = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelgrp + zres_ext05r * zsrelmax + zres_ext05r * zcrelmax
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext05r_smax <- julia_eval("results_study3_ext05r_smax = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelgrp + zres_ext06 * zsrelmax + zres_ext06 * zcrelmax
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext06_smax <- julia_eval("results_study3_ext06_smax = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelgrp + zres_ext07r * zsrelmax + zres_ext07r * zcrelmax
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext07r_smax <- julia_eval("results_study3_ext07r_smax = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelgrp + zres_ext03 * zsrelmax + zres_ext03 * zcrelmax
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext03_smax <- julia_eval("results_study3_ext03_smax = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelgrp + zres_ext04 * zsrelmax + zres_ext04 * zcrelmax
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext04_smax <- julia_eval("results_study3_ext04_smax = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelgrp + zres_opn02 * zsrelmax + zres_opn02 * zcrelmax
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn02_smax <- julia_eval("results_study3_opn02_smax = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelgrp + zres_opn03 * zsrelmax + zres_opn03 * zcrelmax
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn03_smax <- julia_eval("results_study3_opn03_smax = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelgrp + zres_opn05 * zsrelmax + zres_opn05 * zcrelmax
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn05_smax <- julia_eval("results_study3_opn05_smax = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelgrp + zres_opn07r * zsrelmax + zres_opn07r * zcrelmax
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn07r_smax <- julia_eval("results_study3_opn07r_smax = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelgrp + zres_opn08 * zsrelmax + zres_opn08 * zcrelmax
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn08_smax <- julia_eval("results_study3_opn08_smax = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelgrp + zres_opn06 * zsrelmax + zres_opn06 * zcrelmax
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn06_smax <- julia_eval("results_study3_opn06_smax = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelgrp + zres_opn09r * zsrelmax + zres_opn09r * zcrelmax
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn09r_smax <- julia_eval("results_study3_opn09r_smax = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelgrp + zres_opn10 * zsrelmax + zres_opn10 * zcrelmax
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn10_smax <- julia_eval("results_study3_opn10_smax = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelgrp + zres_neu01 * zsrelmax + zres_neu01 * zcrelmax
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu01_smax <- julia_eval("results_study3_neu01_smax = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelgrp + zres_neu06 * zsrelmax + zres_neu06 * zcrelmax
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu06_smax <- julia_eval("results_study3_neu06_smax = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelgrp + zres_neu02r * zsrelmax + zres_neu02r * zcrelmax
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu02r_smax <- julia_eval("results_study3_neu02r_smax = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelgrp + zres_neu04 * zsrelmax + zres_neu04 * zcrelmax
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu04_smax <- julia_eval("results_study3_neu04_smax = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelgrp + zres_neu07r * zsrelmax + zres_neu07r * zcrelmax
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu07r_smax <- julia_eval("results_study3_neu07r_smax = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelgrp + zres_neu08 * zsrelmax + zres_neu08 * zcrelmax
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu08_smax <- julia_eval("results_study3_neu08_smax = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##most religious cities in most religious states in most religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelmax + zres_agr02 * zsrelmax + zres_agr02 * zcrelmax
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr02_amax <- julia_eval("results_study3_agr02_amax = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelmax + zres_agr05 * zsrelmax + zres_agr05 * zcrelmax
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr05_amax <- julia_eval("results_study3_agr05_amax = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelmax + zres_agr06r * zsrelmax + zres_agr06r * zcrelmax
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr06r_amax <- julia_eval("results_study3_agr06r_amax = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelmax + zres_agr07 * zsrelmax + zres_agr07 * zcrelmax
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr07_amax <- julia_eval("results_study3_agr07_amax = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelmax + zres_agr01r * zsrelmax + zres_agr01r * zcrelmax
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr01r_amax <- julia_eval("results_study3_agr01r_amax = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelmax + zres_agr03r * zsrelmax + zres_agr03r * zcrelmax
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr03r_amax <- julia_eval("results_study3_agr03r_amax = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelmax + zres_agr04 * zsrelmax + zres_agr04 * zcrelmax
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_agr04_amax <- julia_eval("results_study3_agr04_amax = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelmax + zres_cns02r * zsrelmax + zres_cns02r * zcrelmax
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns02r_amax <- julia_eval("results_study3_cns02r_amax = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelmax + zres_cns04r * zsrelmax + zres_cns04r * zcrelmax
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns04r_amax <- julia_eval("results_study3_cns04r_amax = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelmax + zres_cns03 * zsrelmax + zres_cns03 * zcrelmax
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns03_amax <- julia_eval("results_study3_cns03_amax = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelmax + zres_cns05r * zsrelmax + zres_cns05r * zcrelmax
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns05r_amax <- julia_eval("results_study3_cns05r_amax = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelmax + zres_cns06 * zsrelmax + zres_cns06 * zcrelmax
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns06_amax <- julia_eval("results_study3_cns06_amax = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelmax + zres_cns08 * zsrelmax + zres_cns08 * zcrelmax
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns08_amax <- julia_eval("results_study3_cns08_amax = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelmax + zres_cns09r * zsrelmax + zres_cns09r * zcrelmax
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_cns09r_amax <- julia_eval("results_study3_cns09r_amax = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelmax + zres_ext01 * zsrelmax + zres_ext01 * zcrelmax
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext01_amax <- julia_eval("results_study3_ext01_amax = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelmax + zres_ext02r * zsrelmax + zres_ext02r * zcrelmax
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext02r_amax <- julia_eval("results_study3_ext02r_amax = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelmax + zres_ext05r * zsrelmax + zres_ext05r * zcrelmax
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext05r_amax <- julia_eval("results_study3_ext05r_amax = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelmax + zres_ext06 * zsrelmax + zres_ext06 * zcrelmax
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext06_amax <- julia_eval("results_study3_ext06_amax = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelmax + zres_ext07r * zsrelmax + zres_ext07r * zcrelmax
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext07r_amax <- julia_eval("results_study3_ext07r_amax = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelmax + zres_ext03 * zsrelmax + zres_ext03 * zcrelmax
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext03_amax <- julia_eval("results_study3_ext03_amax = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelmax + zres_ext04 * zsrelmax + zres_ext04 * zcrelmax
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_ext04_amax <- julia_eval("results_study3_ext04_amax = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelmax + zres_opn02 * zsrelmax + zres_opn02 * zcrelmax
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn02_amax <- julia_eval("results_study3_opn02_amax = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelmax + zres_opn03 * zsrelmax + zres_opn03 * zcrelmax
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn03_amax <- julia_eval("results_study3_opn03_amax = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelmax + zres_opn05 * zsrelmax + zres_opn05 * zcrelmax
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn05_amax <- julia_eval("results_study3_opn05_amax = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelmax + zres_opn07r * zsrelmax + zres_opn07r * zcrelmax
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn07r_amax <- julia_eval("results_study3_opn07r_amax = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelmax + zres_opn08 * zsrelmax + zres_opn08 * zcrelmax
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn08_amax <- julia_eval("results_study3_opn08_amax = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelmax + zres_opn06 * zsrelmax + zres_opn06 * zcrelmax
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn06_amax <- julia_eval("results_study3_opn06_amax = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelmax + zres_opn09r * zsrelmax + zres_opn09r * zcrelmax
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn09r_amax <- julia_eval("results_study3_opn09r_amax = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelmax + zres_opn10 * zsrelmax + zres_opn10 * zcrelmax
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_opn10_amax <- julia_eval("results_study3_opn10_amax = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelmax + zres_neu01 * zsrelmax + zres_neu01 * zcrelmax
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu01_amax <- julia_eval("results_study3_neu01_amax = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelmax + zres_neu06 * zsrelmax + zres_neu06 * zcrelmax
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu06_amax <- julia_eval("results_study3_neu06_amax = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelmax + zres_neu02r * zsrelmax + zres_neu02r * zcrelmax
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu02r_amax <- julia_eval("results_study3_neu02r_amax = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelmax + zres_neu04 * zsrelmax + zres_neu04 * zcrelmax
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu04_amax <- julia_eval("results_study3_neu04_amax = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelmax + zres_neu07r * zsrelmax + zres_neu07r * zcrelmax
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu07r_amax <- julia_eval("results_study3_neu07r_amax = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelmax + zres_neu08 * zsrelmax + zres_neu08 * zcrelmax
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelmax) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelmax) | cnt) + ((0 + zsrelmax) | cnt)), dat_nuances)")
results_study3_neu08_amax <- julia_eval("results_study3_neu08_amax = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelgrp + zres_agr02 * zsrelgrp + zres_agr02 * zcrelmin
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr02_cmin <- julia_eval("results_study3_agr02_cmin = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelgrp + zres_agr05 * zsrelgrp + zres_agr05 * zcrelmin
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr05_cmin <- julia_eval("results_study3_agr05_cmin = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelgrp + zres_agr06r * zsrelgrp + zres_agr06r * zcrelmin
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr06r_cmin <- julia_eval("results_study3_agr06r_cmin = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelgrp + zres_agr07 * zsrelgrp + zres_agr07 * zcrelmin
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr07_cmin <- julia_eval("results_study3_agr07_cmin = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelgrp + zres_agr01r * zsrelgrp + zres_agr01r * zcrelmin
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr01r_cmin <- julia_eval("results_study3_agr01r_cmin = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelgrp + zres_agr03r * zsrelgrp + zres_agr03r * zcrelmin
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr03r_cmin <- julia_eval("results_study3_agr03r_cmin = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelgrp + zres_agr04 * zsrelgrp + zres_agr04 * zcrelmin
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_agr04_cmin <- julia_eval("results_study3_agr04_cmin = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelgrp + zres_cns02r * zsrelgrp + zres_cns02r * zcrelmin
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns02r_cmin <- julia_eval("results_study3_cns02r_cmin = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelgrp + zres_cns04r * zsrelgrp + zres_cns04r * zcrelmin
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns04r_cmin <- julia_eval("results_study3_cns04r_cmin = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelgrp + zres_cns03 * zsrelgrp + zres_cns03 * zcrelmin
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns03_cmin <- julia_eval("results_study3_cns03_cmin = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelgrp + zres_cns05r * zsrelgrp + zres_cns05r * zcrelmin
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns05r_cmin <- julia_eval("results_study3_cns05r_cmin = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelgrp + zres_cns06 * zsrelgrp + zres_cns06 * zcrelmin
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns06_cmin <- julia_eval("results_study3_cns06_cmin = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelgrp + zres_cns08 * zsrelgrp + zres_cns08 * zcrelmin
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns08_cmin <- julia_eval("results_study3_cns08_cmin = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelgrp + zres_cns09r * zsrelgrp + zres_cns09r * zcrelmin
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_cns09r_cmin <- julia_eval("results_study3_cns09r_cmin = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelgrp + zres_ext01 * zsrelgrp + zres_ext01 * zcrelmin
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext01_cmin <- julia_eval("results_study3_ext01_cmin = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelgrp + zres_ext02r * zsrelgrp + zres_ext02r * zcrelmin
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext02r_cmin <- julia_eval("results_study3_ext02r_cmin = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelgrp + zres_ext05r * zsrelgrp + zres_ext05r * zcrelmin
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext05r_cmin <- julia_eval("results_study3_ext05r_cmin = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelgrp + zres_ext06 * zsrelgrp + zres_ext06 * zcrelmin
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext06_cmin <- julia_eval("results_study3_ext06_cmin = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelgrp + zres_ext07r * zsrelgrp + zres_ext07r * zcrelmin
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext07r_cmin <- julia_eval("results_study3_ext07r_cmin = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelgrp + zres_ext03 * zsrelgrp + zres_ext03 * zcrelmin
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext03_cmin <- julia_eval("results_study3_ext03_cmin = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelgrp + zres_ext04 * zsrelgrp + zres_ext04 * zcrelmin
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_ext04_cmin <- julia_eval("results_study3_ext04_cmin = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelgrp + zres_opn02 * zsrelgrp + zres_opn02 * zcrelmin
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn02_cmin <- julia_eval("results_study3_opn02_cmin = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelgrp + zres_opn03 * zsrelgrp + zres_opn03 * zcrelmin
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn03_cmin <- julia_eval("results_study3_opn03_cmin = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelgrp + zres_opn05 * zsrelgrp + zres_opn05 * zcrelmin
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn05_cmin <- julia_eval("results_study3_opn05_cmin = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelgrp + zres_opn07r * zsrelgrp + zres_opn07r * zcrelmin
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn07r_cmin <- julia_eval("results_study3_opn07r_cmin = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelgrp + zres_opn08 * zsrelgrp + zres_opn08 * zcrelmin
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn08_cmin <- julia_eval("results_study3_opn08_cmin = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelgrp + zres_opn06 * zsrelgrp + zres_opn06 * zcrelmin
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn06_cmin <- julia_eval("results_study3_opn06_cmin = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelgrp + zres_opn09r * zsrelgrp + zres_opn09r * zcrelmin
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn09r_cmin <- julia_eval("results_study3_opn09r_cmin = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelgrp + zres_opn10 * zsrelgrp + zres_opn10 * zcrelmin
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_opn10_cmin <- julia_eval("results_study3_opn10_cmin = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelgrp + zres_neu01 * zsrelgrp + zres_neu01 * zcrelmin
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu01_cmin <- julia_eval("results_study3_neu01_cmin = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelgrp + zres_neu06 * zsrelgrp + zres_neu06 * zcrelmin
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu06_cmin <- julia_eval("results_study3_neu06_cmin = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelgrp + zres_neu02r * zsrelgrp + zres_neu02r * zcrelmin
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu02r_cmin <- julia_eval("results_study3_neu02r_cmin = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelgrp + zres_neu04 * zsrelgrp + zres_neu04 * zcrelmin
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu04_cmin <- julia_eval("results_study3_neu04_cmin = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelgrp + zres_neu07r * zsrelgrp + zres_neu07r * zcrelmin
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu07r_cmin <- julia_eval("results_study3_neu07r_cmin = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelgrp + zres_neu08 * zsrelgrp + zres_neu08 * zcrelmin
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelgrp) | cnt)), dat_nuances)")
results_study3_neu08_cmin <- julia_eval("results_study3_neu08_cmin = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious states in least religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelgrp + zres_agr02 * zsrelmin + zres_agr02 * zcrelmin
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr02_smin <- julia_eval("results_study3_agr02_smin = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelgrp + zres_agr05 * zsrelmin + zres_agr05 * zcrelmin
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr05_smin <- julia_eval("results_study3_agr05_smin = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelgrp + zres_agr06r * zsrelmin + zres_agr06r * zcrelmin
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr06r_smin <- julia_eval("results_study3_agr06r_smin = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelgrp + zres_agr07 * zsrelmin + zres_agr07 * zcrelmin
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr07_smin <- julia_eval("results_study3_agr07_smin = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelgrp + zres_agr01r * zsrelmin + zres_agr01r * zcrelmin
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr01r_smin <- julia_eval("results_study3_agr01r_smin = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelgrp + zres_agr03r * zsrelmin + zres_agr03r * zcrelmin
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr03r_smin <- julia_eval("results_study3_agr03r_smin = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelgrp + zres_agr04 * zsrelmin + zres_agr04 * zcrelmin
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr04_smin <- julia_eval("results_study3_agr04_smin = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelgrp + zres_cns02r * zsrelmin + zres_cns02r * zcrelmin
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns02r_smin <- julia_eval("results_study3_cns02r_smin = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelgrp + zres_cns04r * zsrelmin + zres_cns04r * zcrelmin
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns04r_smin <- julia_eval("results_study3_cns04r_smin = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelgrp + zres_cns03 * zsrelmin + zres_cns03 * zcrelmin
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns03_smin <- julia_eval("results_study3_cns03_smin = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelgrp + zres_cns05r * zsrelmin + zres_cns05r * zcrelmin
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns05r_smin <- julia_eval("results_study3_cns05r_smin = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelgrp + zres_cns06 * zsrelmin + zres_cns06 * zcrelmin
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns06_smin <- julia_eval("results_study3_cns06_smin = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelgrp + zres_cns08 * zsrelmin + zres_cns08 * zcrelmin
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns08_smin <- julia_eval("results_study3_cns08_smin = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelgrp + zres_cns09r * zsrelmin + zres_cns09r * zcrelmin
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns09r_smin <- julia_eval("results_study3_cns09r_smin = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelgrp + zres_ext01 * zsrelmin + zres_ext01 * zcrelmin
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext01_smin <- julia_eval("results_study3_ext01_smin = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelgrp + zres_ext02r * zsrelmin + zres_ext02r * zcrelmin
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext02r_smin <- julia_eval("results_study3_ext02r_smin = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelgrp + zres_ext05r * zsrelmin + zres_ext05r * zcrelmin
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext05r_smin <- julia_eval("results_study3_ext05r_smin = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelgrp + zres_ext06 * zsrelmin + zres_ext06 * zcrelmin
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext06_smin <- julia_eval("results_study3_ext06_smin = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelgrp + zres_ext07r * zsrelmin + zres_ext07r * zcrelmin
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext07r_smin <- julia_eval("results_study3_ext07r_smin = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelgrp + zres_ext03 * zsrelmin + zres_ext03 * zcrelmin
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext03_smin <- julia_eval("results_study3_ext03_smin = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelgrp + zres_ext04 * zsrelmin + zres_ext04 * zcrelmin
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext04_smin <- julia_eval("results_study3_ext04_smin = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelgrp + zres_opn02 * zsrelmin + zres_opn02 * zcrelmin
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn02_smin <- julia_eval("results_study3_opn02_smin = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelgrp + zres_opn03 * zsrelmin + zres_opn03 * zcrelmin
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn03_smin <- julia_eval("results_study3_opn03_smin = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelgrp + zres_opn05 * zsrelmin + zres_opn05 * zcrelmin
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn05_smin <- julia_eval("results_study3_opn05_smin = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelgrp + zres_opn07r * zsrelmin + zres_opn07r * zcrelmin
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn07r_smin <- julia_eval("results_study3_opn07r_smin = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelgrp + zres_opn08 * zsrelmin + zres_opn08 * zcrelmin
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn08_smin <- julia_eval("results_study3_opn08_smin = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelgrp + zres_opn06 * zsrelmin + zres_opn06 * zcrelmin
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn06_smin <- julia_eval("results_study3_opn06_smin = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelgrp + zres_opn09r * zsrelmin + zres_opn09r * zcrelmin
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn09r_smin <- julia_eval("results_study3_opn09r_smin = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelgrp + zres_opn10 * zsrelmin + zres_opn10 * zcrelmin
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn10_smin <- julia_eval("results_study3_opn10_smin = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelgrp + zres_neu01 * zsrelmin + zres_neu01 * zcrelmin
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu01_smin <- julia_eval("results_study3_neu01_smin = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelgrp + zres_neu06 * zsrelmin + zres_neu06 * zcrelmin
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu06_smin <- julia_eval("results_study3_neu06_smin = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelgrp + zres_neu02r * zsrelmin + zres_neu02r * zcrelmin
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu02r_smin <- julia_eval("results_study3_neu02r_smin = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelgrp + zres_neu04 * zsrelmin + zres_neu04 * zcrelmin
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu04_smin <- julia_eval("results_study3_neu04_smin = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelgrp + zres_neu07r * zsrelmin + zres_neu07r * zcrelmin
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu07r_smin <- julia_eval("results_study3_neu07r_smin = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelgrp + zres_neu08 * zsrelmin + zres_neu08 * zcrelmin
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelgrp) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelgrp) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu08_smin <- julia_eval("results_study3_neu08_smin = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

##least religious cities in least religious states in least religious countries
###A-Altruism
julia_eval("fm2 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr02 * zarelmin + zres_agr02 * zsrelmin + zres_agr02 * zcrelmin
+ (1 | ara) + ((0 + zres_agr02) | ara) + (1 | sta) + ((0 + zres_agr02) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr02) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr02_amin <- julia_eval("results_study3_agr02_amin = rename!(DataFrame([(coeftable(fm2).rownms) (round.(fixef(fm2, false),digits=5)) (round.(((fixef(fm2, false))-1.96*(stderror(fm2))),digits=5)) (round.(((fixef(fm2, false))+1.96*(stderror(fm2))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm5 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr05 * zarelmin + zres_agr05 * zsrelmin + zres_agr05 * zcrelmin
+ (1 | ara) + ((0 + zres_agr05) | ara) + (1 | sta) + ((0 + zres_agr05) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr05) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr05_amin <- julia_eval("results_study3_agr05_amin = rename!(DataFrame([(coeftable(fm5).rownms) (round.(fixef(fm5, false),digits=5)) (round.(((fixef(fm5, false))-1.96*(stderror(fm5))),digits=5)) (round.(((fixef(fm5, false))+1.96*(stderror(fm5))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm6 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr06r * zarelmin + zres_agr06r * zsrelmin + zres_agr06r * zcrelmin
+ (1 | ara) + ((0 + zres_agr06r) | ara) + (1 | sta) + ((0 + zres_agr06r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr06r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr06r_amin <- julia_eval("results_study3_agr06r_amin = rename!(DataFrame([(coeftable(fm6).rownms) (round.(fixef(fm6, false),digits=5)) (round.(((fixef(fm6, false))-1.96*(stderror(fm6))),digits=5)) (round.(((fixef(fm6, false))+1.96*(stderror(fm6))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm7 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr07 * zarelmin + zres_agr07 * zsrelmin + zres_agr07 * zcrelmin
+ (1 | ara) + ((0 + zres_agr07) | ara) + (1 | sta) + ((0 + zres_agr07) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr07) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr07_amin <- julia_eval("results_study3_agr07_amin = rename!(DataFrame([(coeftable(fm7).rownms) (round.(fixef(fm7, false),digits=5)) (round.(((fixef(fm7, false))-1.96*(stderror(fm7))),digits=5)) (round.(((fixef(fm7, false))+1.96*(stderror(fm7))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###A-Compliance
julia_eval("fm1 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr01r * zarelmin + zres_agr01r * zsrelmin + zres_agr01r * zcrelmin
+ (1 | ara) + ((0 + zres_agr01r) | ara) + (1 | sta) + ((0 + zres_agr01r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr01r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr01r_amin <- julia_eval("results_study3_agr01r_amin = rename!(DataFrame([(coeftable(fm1).rownms) (round.(fixef(fm1, false),digits=5)) (round.(((fixef(fm1, false))-1.96*(stderror(fm1))),digits=5)) (round.(((fixef(fm1, false))+1.96*(stderror(fm1))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm3 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr03r * zarelmin + zres_agr03r * zsrelmin + zres_agr03r * zcrelmin
+ (1 | ara) + ((0 + zres_agr03r) | ara) + (1 | sta) + ((0 + zres_agr03r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr03r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr03r_amin <- julia_eval("results_study3_agr03r_amin = rename!(DataFrame([(coeftable(fm3).rownms) (round.(fixef(fm3, false),digits=5)) (round.(((fixef(fm3, false))-1.96*(stderror(fm3))),digits=5)) (round.(((fixef(fm3, false))+1.96*(stderror(fm3))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm4 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_agr04 * zarelmin + zres_agr04 * zsrelmin + zres_agr04 * zcrelmin
+ (1 | ara) + ((0 + zres_agr04) | ara) + (1 | sta) + ((0 + zres_agr04) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_agr04) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_agr04_amin <- julia_eval("results_study3_agr04_amin = rename!(DataFrame([(coeftable(fm4).rownms) (round.(fixef(fm4, false),digits=5)) (round.(((fixef(fm4, false))-1.96*(stderror(fm4))),digits=5)) (round.(((fixef(fm4, false))+1.96*(stderror(fm4))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Order
julia_eval("fm8 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns02r * zarelmin + zres_cns02r * zsrelmin + zres_cns02r * zcrelmin
+ (1 | ara) + ((0 + zres_cns02r) | ara) + (1 | sta) + ((0 + zres_cns02r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns02r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns02r_amin <- julia_eval("results_study3_cns02r_amin = rename!(DataFrame([(coeftable(fm8).rownms) (round.(fixef(fm8, false),digits=5)) (round.(((fixef(fm8, false))-1.96*(stderror(fm8))),digits=5)) (round.(((fixef(fm8, false))+1.96*(stderror(fm8))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm10 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns04r * zarelmin + zres_cns04r * zsrelmin + zres_cns04r * zcrelmin
+ (1 | ara) + ((0 + zres_cns04r) | ara) + (1 | sta) + ((0 + zres_cns04r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns04r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns04r_amin <- julia_eval("results_study3_cns04r_amin = rename!(DataFrame([(coeftable(fm10).rownms) (round.(fixef(fm10, false),digits=5)) (round.(((fixef(fm10, false))-1.96*(stderror(fm10))),digits=5)) (round.(((fixef(fm10, false))+1.96*(stderror(fm10))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###C-Self-Discipline
julia_eval("fm9 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns03 * zarelmin + zres_cns03 * zsrelmin + zres_cns03 * zcrelmin
+ (1 | ara) + ((0 + zres_cns03) | ara) + (1 | sta) + ((0 + zres_cns03) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns03) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns03_amin <- julia_eval("results_study3_cns03_amin = rename!(DataFrame([(coeftable(fm9).rownms) (round.(fixef(fm9, false),digits=5)) (round.(((fixef(fm9, false))-1.96*(stderror(fm9))),digits=5)) (round.(((fixef(fm9, false))+1.96*(stderror(fm9))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm11 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns05r * zarelmin + zres_cns05r * zsrelmin + zres_cns05r * zcrelmin
+ (1 | ara) + ((0 + zres_cns05r) | ara) + (1 | sta) + ((0 + zres_cns05r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns05r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns05r_amin <- julia_eval("results_study3_cns05r_amin = rename!(DataFrame([(coeftable(fm11).rownms) (round.(fixef(fm11, false),digits=5)) (round.(((fixef(fm11, false))-1.96*(stderror(fm11))),digits=5)) (round.(((fixef(fm11, false))+1.96*(stderror(fm11))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm12 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns06 * zarelmin + zres_cns06 * zsrelmin + zres_cns06 * zcrelmin
+ (1 | ara) + ((0 + zres_cns06) | ara) + (1 | sta) + ((0 + zres_cns06) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns06) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns06_amin <- julia_eval("results_study3_cns06_amin = rename!(DataFrame([(coeftable(fm12).rownms) (round.(fixef(fm12, false),digits=5)) (round.(((fixef(fm12, false))-1.96*(stderror(fm12))),digits=5)) (round.(((fixef(fm12, false))+1.96*(stderror(fm12))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm13 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns08 * zarelmin + zres_cns08 * zsrelmin + zres_cns08 * zcrelmin
+ (1 | ara) + ((0 + zres_cns08) | ara) + (1 | sta) + ((0 + zres_cns08) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns08) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns08_amin <- julia_eval("results_study3_cns08_amin = rename!(DataFrame([(coeftable(fm13).rownms) (round.(fixef(fm13, false),digits=5)) (round.(((fixef(fm13, false))-1.96*(stderror(fm13))),digits=5)) (round.(((fixef(fm13, false))+1.96*(stderror(fm13))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm14 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_cns09r * zarelmin + zres_cns09r * zsrelmin + zres_cns09r * zcrelmin
+ (1 | ara) + ((0 + zres_cns09r) | ara) + (1 | sta) + ((0 + zres_cns09r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_cns09r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_cns09r_amin <- julia_eval("results_study3_cns09r_amin = rename!(DataFrame([(coeftable(fm14).rownms) (round.(fixef(fm14, false),digits=5)) (round.(((fixef(fm14, false))-1.96*(stderror(fm14))),digits=5)) (round.(((fixef(fm14, false))+1.96*(stderror(fm14))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Assertiveness
julia_eval("fm15 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext01 * zarelmin + zres_ext01 * zsrelmin + zres_ext01 * zcrelmin
+ (1 | ara) + ((0 + zres_ext01) | ara) + (1 | sta) + ((0 + zres_ext01) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext01) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext01_amin <- julia_eval("results_study3_ext01_amin = rename!(DataFrame([(coeftable(fm15).rownms) (round.(fixef(fm15, false),digits=5)) (round.(((fixef(fm15, false))-1.96*(stderror(fm15))),digits=5)) (round.(((fixef(fm15, false))+1.96*(stderror(fm15))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm16 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext02r * zarelmin + zres_ext02r * zsrelmin + zres_ext02r * zcrelmin
+ (1 | ara) + ((0 + zres_ext02r) | ara) + (1 | sta) + ((0 + zres_ext02r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext02r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext02r_amin <- julia_eval("results_study3_ext02r_amin = rename!(DataFrame([(coeftable(fm16).rownms) (round.(fixef(fm16, false),digits=5)) (round.(((fixef(fm16, false))-1.96*(stderror(fm16))),digits=5)) (round.(((fixef(fm16, false))+1.96*(stderror(fm16))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm19 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext05r * zarelmin + zres_ext05r * zsrelmin + zres_ext05r * zcrelmin
+ (1 | ara) + ((0 + zres_ext05r) | ara) + (1 | sta) + ((0 + zres_ext05r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext05r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext05r_amin <- julia_eval("results_study3_ext05r_amin = rename!(DataFrame([(coeftable(fm19).rownms) (round.(fixef(fm19, false),digits=5)) (round.(((fixef(fm19, false))-1.96*(stderror(fm19))),digits=5)) (round.(((fixef(fm19, false))+1.96*(stderror(fm19))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm20 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext06 * zarelmin + zres_ext06 * zsrelmin + zres_ext06 * zcrelmin
+ (1 | ara) + ((0 + zres_ext06) | ara) + (1 | sta) + ((0 + zres_ext06) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext06) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext06_amin <- julia_eval("results_study3_ext06_amin = rename!(DataFrame([(coeftable(fm20).rownms) (round.(fixef(fm20, false),digits=5)) (round.(((fixef(fm20, false))-1.96*(stderror(fm20))),digits=5)) (round.(((fixef(fm20, false))+1.96*(stderror(fm20))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm21 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext07r * zarelmin + zres_ext07r * zsrelmin + zres_ext07r * zcrelmin
+ (1 | ara) + ((0 + zres_ext07r) | ara) + (1 | sta) + ((0 + zres_ext07r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext07r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext07r_amin <- julia_eval("results_study3_ext07r_amin = rename!(DataFrame([(coeftable(fm21).rownms) (round.(fixef(fm21, false),digits=5)) (round.(((fixef(fm21, false))-1.96*(stderror(fm21))),digits=5)) (round.(((fixef(fm21, false))+1.96*(stderror(fm21))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###E-Activity
julia_eval("fm17 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext03 * zarelmin + zres_ext03 * zsrelmin + zres_ext03 * zcrelmin
+ (1 | ara) + ((0 + zres_ext03) | ara) + (1 | sta) + ((0 + zres_ext03) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext03) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext03_amin <- julia_eval("results_study3_ext03_amin = rename!(DataFrame([(coeftable(fm17).rownms) (round.(fixef(fm17, false),digits=5)) (round.(((fixef(fm17, false))-1.96*(stderror(fm17))),digits=5)) (round.(((fixef(fm17, false))+1.96*(stderror(fm17))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm18 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_ext04 * zarelmin + zres_ext04 * zsrelmin + zres_ext04 * zcrelmin
+ (1 | ara) + ((0 + zres_ext04) | ara) + (1 | sta) + ((0 + zres_ext04) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_ext04) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_ext04_amin <- julia_eval("results_study3_ext04_amin = rename!(DataFrame([(coeftable(fm18).rownms) (round.(fixef(fm18, false),digits=5)) (round.(((fixef(fm18, false))-1.96*(stderror(fm18))),digits=5)) (round.(((fixef(fm18, false))+1.96*(stderror(fm18))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Ideas
julia_eval("fm22 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn02 * zarelmin + zres_opn02 * zsrelmin + zres_opn02 * zcrelmin
+ (1 | ara) + ((0 + zres_opn02) | ara) + (1 | sta) + ((0 + zres_opn02) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn02) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn02_amin <- julia_eval("results_study3_opn02_amin = rename!(DataFrame([(coeftable(fm22).rownms) (round.(fixef(fm22, false),digits=5)) (round.(((fixef(fm22, false))-1.96*(stderror(fm22))),digits=5)) (round.(((fixef(fm22, false))+1.96*(stderror(fm22))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm23 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn03 * zarelmin + zres_opn03 * zsrelmin + zres_opn03 * zcrelmin
+ (1 | ara) + ((0 + zres_opn03) | ara) + (1 | sta) + ((0 + zres_opn03) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn03) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn03_amin <- julia_eval("results_study3_opn03_amin = rename!(DataFrame([(coeftable(fm23).rownms) (round.(fixef(fm23, false),digits=5)) (round.(((fixef(fm23, false))-1.96*(stderror(fm23))),digits=5)) (round.(((fixef(fm23, false))+1.96*(stderror(fm23))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm24 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn05 * zarelmin + zres_opn05 * zsrelmin + zres_opn05 * zcrelmin
+ (1 | ara) + ((0 + zres_opn05) | ara) + (1 | sta) + ((0 + zres_opn05) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn05) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn05_amin <- julia_eval("results_study3_opn05_amin = rename!(DataFrame([(coeftable(fm24).rownms) (round.(fixef(fm24, false),digits=5)) (round.(((fixef(fm24, false))-1.96*(stderror(fm24))),digits=5)) (round.(((fixef(fm24, false))+1.96*(stderror(fm24))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm26 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn07r * zarelmin + zres_opn07r * zsrelmin + zres_opn07r * zcrelmin
+ (1 | ara) + ((0 + zres_opn07r) | ara) + (1 | sta) + ((0 + zres_opn07r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn07r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn07r_amin <- julia_eval("results_study3_opn07r_amin = rename!(DataFrame([(coeftable(fm26).rownms) (round.(fixef(fm26, false),digits=5)) (round.(((fixef(fm26, false))-1.96*(stderror(fm26))),digits=5)) (round.(((fixef(fm26, false))+1.96*(stderror(fm26))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm27 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn08 * zarelmin + zres_opn08 * zsrelmin + zres_opn08 * zcrelmin
+ (1 | ara) + ((0 + zres_opn08) | ara) + (1 | sta) + ((0 + zres_opn08) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn08) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn08_amin <- julia_eval("results_study3_opn08_amin = rename!(DataFrame([(coeftable(fm27).rownms) (round.(fixef(fm27, false),digits=5)) (round.(((fixef(fm27, false))-1.96*(stderror(fm27))),digits=5)) (round.(((fixef(fm27, false))+1.96*(stderror(fm27))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###O-Aesthetics
julia_eval("fm25 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn06 * zarelmin + zres_opn06 * zsrelmin + zres_opn06 * zcrelmin
+ (1 | ara) + ((0 + zres_opn06) | ara) + (1 | sta) + ((0 + zres_opn06) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn06) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn06_amin <- julia_eval("results_study3_opn06_amin = rename!(DataFrame([(coeftable(fm25).rownms) (round.(fixef(fm25, false),digits=5)) (round.(((fixef(fm25, false))-1.96*(stderror(fm25))),digits=5)) (round.(((fixef(fm25, false))+1.96*(stderror(fm25))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm28 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn09r * zarelmin + zres_opn09r * zsrelmin + zres_opn09r * zcrelmin
+ (1 | ara) + ((0 + zres_opn09r) | ara) + (1 | sta) + ((0 + zres_opn09r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn09r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn09r_amin <- julia_eval("results_study3_opn09r_amin = rename!(DataFrame([(coeftable(fm28).rownms) (round.(fixef(fm28, false),digits=5)) (round.(((fixef(fm28, false))-1.96*(stderror(fm28))),digits=5)) (round.(((fixef(fm28, false))+1.96*(stderror(fm28))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm29 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_opn10 * zarelmin + zres_opn10 * zsrelmin + zres_opn10 * zcrelmin
+ (1 | ara) + ((0 + zres_opn10) | ara) + (1 | sta) + ((0 + zres_opn10) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_opn10) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_opn10_amin <- julia_eval("results_study3_opn10_amin = rename!(DataFrame([(coeftable(fm29).rownms) (round.(fixef(fm29, false),digits=5)) (round.(((fixef(fm29, false))-1.96*(stderror(fm29))),digits=5)) (round.(((fixef(fm29, false))+1.96*(stderror(fm29))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Depression
julia_eval("fm30 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu01 * zarelmin + zres_neu01 * zsrelmin + zres_neu01 * zcrelmin
+ (1 | ara) + ((0 + zres_neu01) | ara) + (1 | sta) + ((0 + zres_neu01) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu01) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu01_amin <- julia_eval("results_study3_neu01_amin = rename!(DataFrame([(coeftable(fm30).rownms) (round.(fixef(fm30, false),digits=5)) (round.(((fixef(fm30, false))-1.96*(stderror(fm30))),digits=5)) (round.(((fixef(fm30, false))+1.96*(stderror(fm30))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm33 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu06 * zarelmin + zres_neu06 * zsrelmin + zres_neu06 * zcrelmin
+ (1 | ara) + ((0 + zres_neu06) | ara) + (1 | sta) + ((0 + zres_neu06) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu06) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu06_amin <- julia_eval("results_study3_neu06_amin = rename!(DataFrame([(coeftable(fm33).rownms) (round.(fixef(fm33, false),digits=5)) (round.(((fixef(fm33, false))-1.96*(stderror(fm33))),digits=5)) (round.(((fixef(fm33, false))+1.96*(stderror(fm33))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

###N-Anxiety
julia_eval("fm31 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu02r * zarelmin + zres_neu02r * zsrelmin + zres_neu02r * zcrelmin
+ (1 | ara) + ((0 + zres_neu02r) | ara) + (1 | sta) + ((0 + zres_neu02r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu02r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu02r_amin <- julia_eval("results_study3_neu02r_amin = rename!(DataFrame([(coeftable(fm31).rownms) (round.(fixef(fm31, false),digits=5)) (round.(((fixef(fm31, false))-1.96*(stderror(fm31))),digits=5)) (round.(((fixef(fm31, false))+1.96*(stderror(fm31))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm32 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu04 * zarelmin + zres_neu04 * zsrelmin + zres_neu04 * zcrelmin
+ (1 | ara) + ((0 + zres_neu04) | ara) + (1 | sta) + ((0 + zres_neu04) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu04) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu04_amin <- julia_eval("results_study3_neu04_amin = rename!(DataFrame([(coeftable(fm32).rownms) (round.(fixef(fm32, false),digits=5)) (round.(((fixef(fm32, false))-1.96*(stderror(fm32))),digits=5)) (round.(((fixef(fm32, false))+1.96*(stderror(fm32))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm34 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu07r * zarelmin + zres_neu07r * zsrelmin + zres_neu07r * zcrelmin
+ (1 | ara) + ((0 + zres_neu07r) | ara) + (1 | sta) + ((0 + zres_neu07r) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu07r) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu07r_amin <- julia_eval("results_study3_neu07r_amin = rename!(DataFrame([(coeftable(fm34).rownms) (round.(fixef(fm34, false),digits=5)) (round.(((fixef(fm34, false))-1.96*(stderror(fm34))),digits=5)) (round.(((fixef(fm34, false))+1.96*(stderror(fm34))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")

julia_eval("fm35 = fit(LinearMixedModel, @formula(zprel ~ 1 + zres_neu08 * zarelmin + zres_neu08 * zsrelmin + zres_neu08 * zcrelmin
+ (1 | ara) + ((0 + zres_neu08) | ara) + (1 | sta) + ((0 + zres_neu08) | sta) + ((0 + zarelmin) | sta)
+ (1 | cnt) + ((0 + zres_neu08) | cnt) + ((0 + zarelmin) | cnt) + ((0 + zsrelmin) | cnt)), dat_nuances)")
results_study3_neu08_amin <- julia_eval("results_study3_neu08_amin = rename!(DataFrame([(coeftable(fm35).rownms) (round.(fixef(fm35, false),digits=5)) (round.(((fixef(fm35, false))-1.96*(stderror(fm35))),digits=5)) (round.(((fixef(fm35, false))+1.96*(stderror(fm35))),digits=5))]),
 :x1 => :predictor, :x2 => :zPe, :x3 => :lowerCI, :x4 => :upperCI)")
